#############################################################################
##
## Copyright (C) 2021 Riverbank Computing Limited.
## Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
##
## This file is part of the examples of PyQt.
##
## $QT_BEGIN_LICENSE:BSD$
## You may use this file under the terms of the BSD license as follows:
##
## "Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are
## met:
##   * Redistributions of source code must retain the above copyright
##     notice, this list of conditions and the following disclaimer.
##   * Redistributions in binary form must reproduce the above copyright
##     notice, this list of conditions and the following disclaimer in
##     the documentation and/or other materials provided with the
##     distribution.
##   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
##     the names of its contributors may be used to endorse or promote
##     products derived from this software without specific prior written
##     permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
## $QT_END_LICENSE$
##
#############################################################################


import os

from PyQt6.QtCore import QDate, QSize, Qt
from PyQt6.QtGui import QIcon
from PyQt6.QtWidgets import (QApplication, QCheckBox, QComboBox, QDateTimeEdit,
        QDialog, QGridLayout, QGroupBox, QHBoxLayout, QLabel, QLineEdit,
        QListView, QListWidget, QListWidgetItem, QPushButton, QSpinBox,
        QStackedWidget, QVBoxLayout, QWidget)


class ConfigurationPage(QWidget):
    def __init__(self, parent=None):
        super().__init__(parent)

        configGroup = QGroupBox("Server configuration")

        serverLabel = QLabel("Server:")
        serverCombo = QComboBox()
        serverCombo.addItem("Trolltech (Australia)")
        serverCombo.addItem("Trolltech (Germany)")
        serverCombo.addItem("Trolltech (Norway)")
        serverCombo.addItem("Trolltech (People's Republic of China)")
        serverCombo.addItem("Trolltech (USA)")

        serverLayout = QHBoxLayout()
        serverLayout.addWidget(serverLabel)
        serverLayout.addWidget(serverCombo)

        configLayout = QVBoxLayout()
        configLayout.addLayout(serverLayout)
        configGroup.setLayout(configLayout)

        mainLayout = QVBoxLayout()
        mainLayout.addWidget(configGroup)
        mainLayout.addStretch(1)

        self.setLayout(mainLayout)


class UpdatePage(QWidget):
    def __init__(self, parent=None):
        super().__init__(parent)

        updateGroup = QGroupBox("Package selection")
        systemCheckBox = QCheckBox("Update system")
        appsCheckBox = QCheckBox("Update applications")
        docsCheckBox = QCheckBox("Update documentation")

        packageGroup = QGroupBox("Existing packages")

        packageList = QListWidget()
        qtItem = QListWidgetItem(packageList)
        qtItem.setText("Qt")
        qsaItem = QListWidgetItem(packageList)
        qsaItem.setText("QSA")
        teamBuilderItem = QListWidgetItem(packageList)
        teamBuilderItem.setText("Teambuilder")

        startUpdateButton = QPushButton("Start update")

        updateLayout = QVBoxLayout()
        updateLayout.addWidget(systemCheckBox)
        updateLayout.addWidget(appsCheckBox)
        updateLayout.addWidget(docsCheckBox)
        updateGroup.setLayout(updateLayout)

        packageLayout = QVBoxLayout()
        packageLayout.addWidget(packageList)
        packageGroup.setLayout(packageLayout)

        mainLayout = QVBoxLayout()
        mainLayout.addWidget(updateGroup)
        mainLayout.addWidget(packageGroup)
        mainLayout.addSpacing(12)
        mainLayout.addWidget(startUpdateButton)
        mainLayout.addStretch(1)

        self.setLayout(mainLayout)


class QueryPage(QWidget):
    def __init__(self, parent=None):
        super().__init__(parent)

        packagesGroup = QGroupBox("Look for packages")

        nameLabel = QLabel("Name:")
        nameEdit = QLineEdit()

        dateLabel = QLabel("Released after:")
        dateEdit = QDateTimeEdit(QDate.currentDate())

        releasesCheckBox = QCheckBox("Releases")
        upgradesCheckBox = QCheckBox("Upgrades")

        hitsSpinBox = QSpinBox()
        hitsSpinBox.setPrefix("Return up to ")
        hitsSpinBox.setSuffix(" results")
        hitsSpinBox.setSpecialValueText("Return only the first result")
        hitsSpinBox.setMinimum(1)
        hitsSpinBox.setMaximum(100)
        hitsSpinBox.setSingleStep(10)

        startQueryButton = QPushButton("Start query")

        packagesLayout = QGridLayout()
        packagesLayout.addWidget(nameLabel, 0, 0)
        packagesLayout.addWidget(nameEdit, 0, 1)
        packagesLayout.addWidget(dateLabel, 1, 0)
        packagesLayout.addWidget(dateEdit, 1, 1)
        packagesLayout.addWidget(releasesCheckBox, 2, 0)
        packagesLayout.addWidget(upgradesCheckBox, 3, 0)
        packagesLayout.addWidget(hitsSpinBox, 4, 0, 1, 2)
        packagesGroup.setLayout(packagesLayout)

        mainLayout = QVBoxLayout()
        mainLayout.addWidget(packagesGroup)
        mainLayout.addSpacing(12)
        mainLayout.addWidget(startQueryButton)
        mainLayout.addStretch(1)

        self.setLayout(mainLayout)


class ConfigDialog(QDialog):
    def __init__(self, parent=None):
        super().__init__(parent)

        self.contentsWidget = QListWidget()
        self.contentsWidget.setViewMode(QListView.ViewMode.IconMode)
        self.contentsWidget.setIconSize(QSize(96, 84))
        self.contentsWidget.setMovement(QListView.Movement.Static)
        self.contentsWidget.setMaximumWidth(128)
        self.contentsWidget.setSpacing(12)

        self.pagesWidget = QStackedWidget()
        self.pagesWidget.addWidget(ConfigurationPage())
        self.pagesWidget.addWidget(UpdatePage())
        self.pagesWidget.addWidget(QueryPage())

        closeButton = QPushButton("Close")

        self.createIcons()
        self.contentsWidget.setCurrentRow(0)

        closeButton.clicked.connect(self.close)

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(self.contentsWidget)
        horizontalLayout.addWidget(self.pagesWidget, 1)

        buttonsLayout = QHBoxLayout()
        buttonsLayout.addStretch(1)
        buttonsLayout.addWidget(closeButton)

        mainLayout = QVBoxLayout()
        mainLayout.addLayout(horizontalLayout)
        mainLayout.addStretch(1)
        mainLayout.addSpacing(12)
        mainLayout.addLayout(buttonsLayout)

        self.setLayout(mainLayout)

        self.setWindowTitle("Config Dialog")

    def changePage(self, current, previous):
        if not current:
            current = previous

        self.pagesWidget.setCurrentIndex(self.contentsWidget.row(current))

    def createIcons(self):
        images_dir = os.path.join(os.path.dirname(__file__), 'images')

        configButton = QListWidgetItem(self.contentsWidget)
        configButton.setIcon(QIcon(os.path.join(images_dir, 'config.png')))
        configButton.setText("Configuration")
        configButton.setTextAlignment(Qt.AlignmentFlag.AlignHCenter)
        configButton.setFlags(
                Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled)

        updateButton = QListWidgetItem(self.contentsWidget)
        updateButton.setIcon(QIcon(os.path.join(images_dir, 'update.png')))
        updateButton.setText("Update")
        updateButton.setTextAlignment(Qt.AlignmentFlag.AlignHCenter)
        updateButton.setFlags(
                Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled)

        queryButton = QListWidgetItem(self.contentsWidget)
        queryButton.setIcon(QIcon(os.path.join(images_dir, 'query.png')))
        queryButton.setText("Query")
        queryButton.setTextAlignment(Qt.AlignmentFlag.AlignHCenter)
        queryButton.setFlags(
                Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled)

        self.contentsWidget.currentItemChanged.connect(self.changePage)


if __name__ == '__main__':

    import sys

    app = QApplication(sys.argv)
    dialog = ConfigDialog()
    sys.exit(dialog.exec())    



# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import sys

from .lupdate import lupdate


def main():
    """ Update a .ts file from a .py file. """

    import argparse

    from PyQt6.QtCore import PYQT_VERSION_STR

    from .user import UserException

    # The program name.
    PROGRAM_NAME = 'pylupdate6'

    # Parse the command line.
    parser = argparse.ArgumentParser(prog=PROGRAM_NAME,
            description="Python Language Update Tool")

    parser.add_argument('-V', '--version', action='version',
            version=PYQT_VERSION_STR)
    parser.add_argument('--exclude', action='append', metavar="PATTERN",
            help="exclude matching files when reading a directory")
    parser.add_argument('--no-obsolete', '-no-obsolete', action='store_true',
            help="remove any obsolete translated messages")
    parser.add_argument('--no-summary', action='store_true',
            help="suppress the summary")
    parser.add_argument('--ts', '-ts', action='append', metavar="FILE",
            required=True,
            help="a .ts file to update or create")
    parser.add_argument('--verbose', action='store_true',
            help="show progress messages")
    parser.add_argument('file', nargs='+',
            help="the .py or .ui file, or directory to be read")

    args = parser.parse_args()

	# Update the translation files.
    try:
        lupdate(args.file, args.ts, args.no_obsolete, args.no_summary,
                args.verbose, args.exclude)
    except UserException as e:
        print("{0}: {1}".format(PROGRAM_NAME, e), file=sys.stderr)
        return 1
    except:
        if args.verbose:
            import traceback

            traceback.print_exception(*sys.exc_info())
        else:
            print("""An unexpected error occurred.
Check that you are using the latest version of {name} and send an error
report to the PyQt mailing list and include the following information:

- the version of {name} ({version})
- the .py or .ui file that caused the error (as an attachment)
- the verbose output of {name} (use the --verbose flag when calling
  {name})""".format(name=PROGRAM_NAME, version=PYQT_VERSION_STR),
                    file=sys.stderr)

        return 2

    return 0


if __name__ == '__main__':
    sys.exit(main())



#############################################################################
##
## Copyright (C) 2021 Riverbank Computing Limited.
## Copyright (C) 2020 The Qt Company Ltd.
## All rights reserved.
##
## This file is part of the examples of PyQt.
##
## $QT_BEGIN_LICENSE:BSD$
## You may use this file under the terms of the BSD license as follows:
##
## "Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are
## met:
##   * Redistributions of source code must retain the above copyright
##     notice, this list of conditions and the following disclaimer.
##   * Redistributions in binary form must reproduce the above copyright
##     notice, this list of conditions and the following disclaimer in
##     the documentation and/or other materials provided with the
##     distribution.
##   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
##     the names of its contributors may be used to endorse or promote
##     products derived from this software without specific prior written
##     permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
## $QT_END_LICENSE$
##
#############################################################################


import os

from PyQt6.QtCore import QDateTime, QDir, qFuzzyCompare, Qt, QTimer
from PyQt6.QtGui import QAction, QActionGroup, QIcon, QImage, QPixmap
from PyQt6.QtMultimedia import (QAudioInput, QCamera, QImageCapture,
        QMediaFormat, QMediaDevices, QMediaCaptureSession, QMediaMetaData,
        QMediaRecorder)
from PyQt6.QtWidgets import (QApplication, QDialog, QDialogButtonBox,
        QFormLayout, QHBoxLayout, QLineEdit, QMainWindow, QMessageBox,
        QPushButton, QScrollArea, QVBoxLayout, QWidget)

from ui_camera import Ui_Camera
from ui_imagesettings import Ui_ImageSettingsUi
from ui_videosettings import Ui_VideoSettingsUi


class ImageSettings(QDialog):

    def __init__(self, imageCapture, parent=None):
        super().__init__(parent)

        self.ui = Ui_ImageSettingsUi()
        self.imagecapture = imageCapture

        self.ui.setupUi(self)

        self.ui.imageCodecBox.addItem("Default image format", "")
        for f in self.imagecapture.supportedFormats():
            description = QImageCapture.fileFormatDescription(f)
            self.ui.imageCodecBox.addItem(
                    QImageCapture.fileFormatName(f) + ": " + description, f)

        self.ui.imageQualitySlider.setRange(
                QImageCapture.Quality.VeryLowQuality.value,
                QImageCapture.Quality.VeryHighQuality.value)

        self.ui.imageResolutionBox.addItem("Default resolution")
        supportedResolutions = self.imagecapture.captureSession().camera().cameraDevice().photoResolutions()
        for resolution in supportedResolutions:
            self.ui.imageResolutionBox.addItem(
                    "%dx%d" % (resolution.width(), resolution.height()),
                    resolution)

        self.selectComboBoxItem(self.ui.imageCodecBox,
                self.imagecapture.fileFormat())
        self.selectComboBoxItem(self.ui.imageResolutionBox,
                self.imagecapture.resolution())
        self.ui.imageQualitySlider.setValue(self.imagecapture.quality().value)

    def applyImageSettings(self):
        self.imagecapture.setFileFormat(self.boxValue(self.ui.imageCodecBox))
        self.imagecapture.setQuality(
                QImageCapture.Quality(self.ui.imageQualitySlider.value()))
        self.imagecapture.setResolution(
                self.boxValue(self.ui.imageResolutionBox))

    @staticmethod
    def boxValue(box):
        idx = box.currentIndex()
        if idx == -1:
            return None

        return box.itemData(idx)

    @staticmethod
    def selectComboBoxItem(box, value):
        for i in range(box.count()):
            if box.itemData(i) == value:
                box.setCurrentIndex(i)
                break


class VideoSettings(QDialog):

    def __init__(self, mediaRecorder, parent=None):
        super().__init__(parent)

        self.ui = Ui_VideoSettingsUi()
        self.mediaRecorder = mediaRecorder

        self.ui.setupUi(self)

        self.ui.audioCodecBox.addItem("Default audio codec",
                QMediaFormat.AudioCodec.Unspecified)
        for ac in QMediaFormat().supportedAudioCodecs(QMediaFormat.ConversionMode.Encode):
            description = QMediaFormat.audioCodecDescription(ac)
            self.ui.audioCodecBox.addItem(
                    QMediaFormat.audioCodecName(ac) + ": " + description, ac)

        audioDevice = self.mediaRecorder.captureSession().audioInput().device()
        self.ui.audioSampleRateBox.setRange(audioDevice.minimumSampleRate(),
                audioDevice.maximumSampleRate())

        self.ui.videoCodecBox.addItem("Default video codec",
                QMediaFormat.VideoCodec.Unspecified)
        for vc in QMediaFormat().supportedVideoCodecs(QMediaFormat.ConversionMode.Encode):
            description = QMediaFormat.videoCodecDescription(vc)
            self.ui.videoCodecBox.addItem(
                    QMediaFormat.videoCodecName(vc) + ": " + description, vc)

        self.ui.videoResolutionBox.addItem("Default")
        supportedResolutions = self.mediaRecorder.captureSession().camera().cameraDevice().photoResolutions()
        for resolution in supportedResolutions:
            self.ui.videoResolutionBox.addItem(
                    "%dx%d" % (resolution.width(), resolution.height()),
                    resolution)

        self.ui.videoFramerateBox.addItem("Default")
        #supportedFrameRates, _ = self.mediaRecorder.supportedFrameRates()
        #for rate in supportedFrameRates:
        #    self.ui.videoFramerateBox.addItem("%0.2f" % rate, rate)

        self.ui.containerFormatBox.addItem("Default container",
                QMediaFormat.FileFormat.UnspecifiedFormat)
        for fmt in QMediaFormat().supportedFileFormats(QMediaFormat.ConversionMode.Encode):
            description = QMediaFormat.fileFormatDescription(fmt)
            self.ui.containerFormatBox.addItem(
                    QMediaFormat.fileFormatName(fmt) + ": " + description, fmt)

        self.ui.qualitySlider.setRange(
                QMediaRecorder.Quality.VeryLowQuality.value,
                QMediaRecorder.Quality.VeryHighQuality.value)

        mediaFormat = self.mediaRecorder.mediaFormat()
        self.selectComboBoxItem(self.ui.containerFormatBox,
                mediaFormat.fileFormat())
        self.selectComboBoxItem(self.ui.audioCodecBox,
                mediaFormat.audioCodec())
        self.selectComboBoxItem(self.ui.videoCodecBox,
                mediaFormat.videoCodec())

        self.ui.qualitySlider.setValue(self.mediaRecorder.quality().value)
        self.ui.audioSampleRateBox.setValue(
                self.mediaRecorder.audioSampleRate())
        self.selectComboBoxItem(self.ui.videoResolutionBox,
                self.mediaRecorder.videoResolution())

        for i in range(1, self.ui.videoFramerateBox.count()):
            itemRate = self.ui.videoFramerateBox.itemData(i)
            if qFuzzyCompare(itemRate, self.mediaRecorder.videoFrameRate()):
                self.ui.videoFramerateBox.setCurrentIndex(i)
                break

    def applySettings(self):
        mediaFormat = QMediaFormat()
        mediaFormat.setFileFormat(self.boxValue(self.ui.containerFormatBox))
        mediaFormat.setAudioCodec(self.boxValue(self.ui.audioCodecBox))
        mediaFormat.setVideoCodec(self.boxValue(self.ui.videoCodecBox))

        self.mediaRecorder.setMediaFormat(mediaFormat)
        self.mediaRecorder.setQuality(
                QMediaRecorder.Quality(self.ui.qualitySlider.value()))
        self.mediaRecorder.setAudioSampleRate(
                self.ui.audioSampleRateBox.value())
        self.mediaRecorder.setVideoResolution(
                boxValue(self.ui.videoResolutionBox))
        self.mediaRecorder.setVideoFrameRate(
                boxValue(self.ui.videoFramerateBox))

    @staticmethod
    def boxValue(box):
        idx = box.currentIndex()
        if idx == -1:
            return None

        return box.itemData(idx)

    @staticmethod
    def selectComboBoxItem(box, value):
        for i in range(box.count()):
            if box.itemData(i) == value:
                box.setCurrentIndex(i)
                break


class MetaDataDialog(QDialog):

    def __init__(self, parent=None):
        super().__init__(parent)

        self.metaDataFields = {}

        metaDataLayout = QFormLayout()

        for key in QMediaMetaData.Key:
            label = QMediaMetaData.metaDataKeyToString(key)
            field = QLineEdit()
            self.metaDataFields[key] = field

            if key is QMediaMetaData.Key.ThumbnailImage:
                openThumbnail = QPushButton("Open",
                        clicked=self.openThumbnailImage)
                layout = QHBoxLayout()
                layout.addWidget(field)
                layout.addWidget(openThumbnail)
                metaDataLayout.addRow(label, layout)

            elif key is QMediaMetaData.Key.CoverArtImage:
                openCoverArt = QPushButton("Open",
                        clicked=self.openCoverArtImage)
                layout = QHBoxLayout()
                layout.addWidget(field)
                layout.addWidget(openCoverArt)
                metaDataLayout.addRow(label, layout)

            else:
                if key is QMediaMetaData.Key.Title:
                    field.setText("PyQt Camera Example")
                elif key is QMediaMetaData.Key.Author:
                    field.setText("Riverbank Computing")
                elif key is QMediaMetaData.Key.Date:
                    field.setText(QDateTime.currentDateTime().toString())

                metaDataLayout.addRow(label, field)

        viewport = QWidget()
        viewport.setLayout(metaDataLayout)
        scrollArea = QScrollArea()
        scrollArea.setWidget(viewport)
        dialogLayout = QVBoxLayout()
        dialogLayout.addWidget(scrollArea)

        buttonBox = QDialogButtonBox(
                QDialogButtonBox.StandardButton.Ok | QDialogButtonBox.StandardButton.Cancel)
        dialogLayout.addWidget(buttonBox)
        self.setLayout(dialogLayout)

        self.setWindowTitle("Set Metadata")
        self.resize(400, 300)

        buttonBox.accepted.connect(self.accept)
        buttonBox.rejected.connect(self.reject)

    def openThumbnailImage(self):
        fileName, _ = QFileDialog.getOpenFileName(self, "Open Image",
                QDir.currentPath(), "Image Files (*.png *.jpg *.bmp)")

        if fileName:
            self.metaDataFields[QMediaMetaData.Key.ThumbnailImage].setText(
                    fileName)

    def openCoverArtImage(self):
        fileName, _ = QFileDialog.getOpenFileName(self, "Open Image",
                QDir.currentPath(), "Image Files (*.png *.jpg *.bmp)")

        if fileName:
            self.metaDataFields[QMediaMetaData.Key.CoverArtImage].setText(
                    fileName)


class Camera(QMainWindow):

    def __init__(self, parent=None):
        super().__init__(parent)

        self.ui = Ui_Camera()

        self.devices = QMediaDevices()
        self.captureSession = QMediaCaptureSession()
        self.camera = None
        self.imageCapture = None
        self.mediaRecorder = None
        self.isCapturingImage = False
        self.applicationExiting = False
        self.doImageCapture = True
        self.metaDataDialog = None

        self.ui.setupUi(self)

        self.ui.takeImageButton.setIcon(
                QIcon(
                        os.path.join(os.path.dirname(__file__), 'images',
                                'shutter.svg')))

        self.audioInput = QAudioInput()
        self.captureSession.setAudioInput(self.audioInput)

        self.videoDevicesGroup = QActionGroup(self)
        self.videoDevicesGroup.setExclusive(True)

        self.updateCameras()
        self.devices.videoInputsChanged.connect(self.updateCameras)

        self.videoDevicesGroup.triggered.connect(self.updateCameraDevice)
        self.ui.captureWidget.currentChanged.connect(self.updateCaptureMode)

        self.ui.metaDataButton.clicked.connect(self.showMetaDataDialog)

        self.setCamera(QMediaDevices.defaultVideoInput())

    def setCamera(self, cameraDevice):
        self.camera = QCamera(cameraDevice)
        self.captureSession.setCamera(self.camera)

        self.camera.activeChanged.connect(self.updateCameraActive)
        self.camera.errorOccurred.connect(self.displayCameraError)

        self.mediaRecorder = QMediaRecorder()
        self.captureSession.setRecorder(self.mediaRecorder)
        self.mediaRecorder.recorderStateChanged.connect(
                self.updateRecorderState)

        self.imageCapture = QImageCapture()
        self.captureSession.setImageCapture(self.imageCapture)

        self.mediaRecorder.durationChanged.connect(self.updateRecordTime)
        self.mediaRecorder.errorChanged.connect(self.displayRecorderError)

        self.ui.exposureCompensation.valueChanged.connect(
                self.setExposureCompensation)

        self.captureSession.setVideoOutput(self.ui.viewfinder)

        self.updateCameraActive(self.camera.isActive())
        self.updateRecorderState(self.mediaRecorder.recorderState())

        self.imageCapture.readyForCaptureChanged.connect(self.readyForCapture)
        self.imageCapture.imageCaptured.connect(self.processCapturedImage)
        self.imageCapture.imageSaved.connect(self.imageSaved)
        self.imageCapture.errorOccurred.connect(self.displayCaptureError)
        self.readyForCapture(self.imageCapture.isReadyForCapture())

        self.updateCaptureMode()
        self.camera.start()

    def keyPressEvent(self, event):
        if event.isAutoRepeat():
            return

        if event.key() is Qt.Key.Key_CameraFocus:
            self.displayViewfinder()
            self.camera.searchAndLock()
            event.accept()
        elif event.key() is Qt.Key.Key_Camera:
            if self.doImageCapture:
                self.takeImage()
            elif self.mediaRecorder.recorderState() is QMediaRecorder.RecorderState.RecordingState:
                self.stop()
            else:
                self.record()

            event.accept()
        else:
            super().keyPressEvent(event)

    def updateRecordTime(self):
        msg = "Recorded %d sec" % (self.mediaRecorder.duration() // 1000)
        self.ui.statusbar.showMessage(msg)

    def processCapturedImage(self, requestId, img):
        scaledImage = img.scaled(self.ui.viewfinder.size(),
                Qt.AspectRatioMode.KeepAspectRatio,
                Qt.TransformationMode.SmoothTransformation)

        self.ui.lastImagePreviewLabel.setPixmap(QPixmap.fromImage(scaledImage))

        self.displayCapturedImage()
        QTimer.singleShot(4000, self.displayViewfinder)

    def configureCaptureSettings(self):
        if self.doImageCapture:
            self.configureImageSettings()
        else:
            self.configureVideoSettings()

    def configureVideoSettings(self):
        settingsDialog = VideoSettings(self.mediaRecorder)
        settingsDialog.setWindowFlags(
                settingsDialog.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)

        if settingsDialog.exec():
            settingsDialog.applySettings()

    def configureImageSettings(self):
        settingsDialog = ImageSettings(self.imageCapture)
        settingsDialog.setWindowFlags(
                settingsDialog.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)

        if settingsDialog.exec():
            settingsDialog.applyImageSettings()

    def record(self):
        self.mediaRecorder.record()
        self.updateRecordTime()

    def pause(self):
        self.mediaRecorder.pause()

    def stop(self):
        self.mediaRecorder.stop()

    def setMuted(self, muted):
        self.captureSession.audioInput().setMuted(muted)

    def takeImage(self):
        self.isCapturingImage = True
        self.imageCapture.captureToFile()

    def displayCaptureError(self, id, error, errorString):
        QMessageBox.warning(self, "Image Capture Error", errorString)
        self.isCapturingImage = False

    def startCamera(self):
        self.camera.start()

    def stopCamera(self):
        self.camera.stop()

    def updateCaptureMode(self):
        tabIndex = self.ui.captureWidget.currentIndex()
        self.doImageCapture = (tabIndex == 0)

    def updateCameraActive(self, active):
        if active:
            self.ui.actionStartCamera.setEnabled(False)
            self.ui.actionStopCamera.setEnabled(True)
            self.ui.captureWidget.setEnabled(True)
            self.ui.actionSettings.setEnabled(True)
        else:
            self.ui.actionStartCamera.setEnabled(True)
            self.ui.actionStopCamera.setEnabled(False)
            self.ui.captureWidget.setEnabled(False)
            self.ui.actionSettings.setEnabled(False)

    def updateRecorderState(self, state):
        if state is QMediaRecorder.RecorderState.StoppedState:
            self.ui.recordButton.setEnabled(True)
            self.ui.pauseButton.setEnabled(True)
            self.ui.stopButton.setEnabled(False)
            self.ui.metaDataButton.setEnabled(True)
        elif state is QMediaRecorder.RecorderState.PausedState:
            self.ui.recordButton.setEnabled(True)
            self.ui.pauseButton.setEnabled(False)
            self.ui.stopButton.setEnabled(True)
            self.ui.metaDataButton.setEnabled(False)
        elif state is QMediaRecorder.RecorderState.RecordingState:
            self.ui.recordButton.setEnabled(False)
            self.ui.pauseButton.setEnabled(True)
            self.ui.stopButton.setEnabled(True)
            self.ui.metaDataButton.setEnabled(False)

    def setExposureCompensation(self, index):
        self.camera.setExposureCompensation(index * 0.5)

    def displayRecorderError(self):
        if self.mediaRecorder.error() is not QMediaRecorder.Error.NoError:
            QMessageBox.warning(self, "Capture Error",
                    self.mediaRecorder.errorString())

    def displayCameraError(self):
        if self.camera.error() is not QCamers.Error.NoError:
            QMessageBox.warning(self, "Camera Error",
                    self.camera.errorString())

    def updateCameraDevice(self, action):
        self.setCamera(action.data())

    def displayViewfinder(self):
        self.ui.stackedWidget.setCurrentIndex(0)

    def displayCapturedImage(self):
        self.ui.stackedWidget.setCurrentIndex(1)

    def readyForCapture(self, ready):
        self.ui.takeImageButton.setEnabled(ready)

    def imageSaved(self, id, fileName):
        self.ui.statusbar.showMessage(
                "Captured \"%s\"" % QDir.toNativeSeparators(fileName))
        self.isCapturingImage = False

        if self.applicationExiting:
            self.close()

    def closeEvent(self, event):
        if self.isCapturingImage:
            self.setEnabled(False)
            self.applicationExiting = True
            event.ignore()
        else:
            event.accept()

    def updateCameras(self):
        self.ui.menuDevices.clear()

        for cameraDevice in QMediaDevices.videoInputs():
            videoDeviceAction = QAction(cameraDevice.description(),
                    self.videoDevicesGroup)
            videoDeviceAction.setCheckable(True)
            videoDeviceAction.setData(cameraDevice)

            if cameraDevice == QMediaDevices.defaultVideoInput():
                videoDeviceAction.setChecked(True)

            self.ui.menuDevices.addAction(videoDeviceAction)

    def showMetaDataDialog(self):
        if self.metaDataDialog is None:
            self.metaDataDialog = MetaDataDialog(self)

        self.metaDataDialog.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose,
                False)

        if self.metaDataDialog.exec() is QDialog.DialogCode.Accepted:
            self.saveMetaData()

    def saveMetaData(self):
        data = QMediaMetaData()

        for key in QMediaMetaData.Key:
            val = self.metaDataDialog.metaDataFields[key].text()
            if val:
                if key in (QMediaMetaData.Key.CoverArtImage, QMediaMetaData.Key.ThumbnailImage):
                    val = QImage(val)
                elif key is QMediaMetaData.Key.Date:
                    val = QDateTime.fromString(val)

                data.insert(key, val)

        self.mediaRecorder.setMetaData(data)


if __name__ == '__main__':

    import sys

    app = QApplication(sys.argv)

    camera = Camera()
    camera.show()

    sys.exit(app.exec())



#############################################################################
##
## Copyright (C) 2021 Riverbank Computing Limited.
## Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
##
## This file is part of the examples of PyQt.
##
## $QT_BEGIN_LICENSE:BSD$
## You may use this file under the terms of the BSD license as follows:
##
## "Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are
## met:
##   * Redistributions of source code must retain the above copyright
##     notice, this list of conditions and the following disclaimer.
##   * Redistributions in binary form must reproduce the above copyright
##     notice, this list of conditions and the following disclaimer in
##     the documentation and/or other materials provided with the
##     distribution.
##   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
##     the names of its contributors may be used to endorse or promote
##     products derived from this software without specific prior written
##     permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
## $QT_END_LICENSE$
##
#############################################################################


from PyQt6.QtWidgets import (QApplication, QGridLayout, QLabel, QLineEdit,
        QVBoxLayout, QWizard, QWizardPage)


def createIntroPage():
    page = QWizardPage()
    page.setTitle("Introduction")

    label = QLabel(
            "This wizard will help you register your copy of Super Product "
            "Two.")
    label.setWordWrap(True)

    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)

    return page


def createRegistrationPage():
    page = QWizardPage()
    page.setTitle("Registration")
    page.setSubTitle("Please fill both fields.")

    nameLabel = QLabel("Name:")
    nameLineEdit = QLineEdit()

    emailLabel = QLabel("Email address:")
    emailLineEdit = QLineEdit()

    layout = QGridLayout()
    layout.addWidget(nameLabel, 0, 0)
    layout.addWidget(nameLineEdit, 0, 1)
    layout.addWidget(emailLabel, 1, 0)
    layout.addWidget(emailLineEdit, 1, 1)
    page.setLayout(layout)

    return page


def createConclusionPage():
    page = QWizardPage()
    page.setTitle("Conclusion")

    label = QLabel("You are now successfully registered. Have a nice day!")
    label.setWordWrap(True)

    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)

    return page


if __name__ == '__main__':

    import sys

    app = QApplication(sys.argv)

    wizard = QWizard()
    wizard.addPage(createIntroPage())
    wizard.addPage(createRegistrationPage())
    wizard.addPage(createConclusionPage())

    wizard.setWindowTitle("Trivial Wizard")
    wizard.show()

    sys.exit(app.exec())



# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..uic import UIFile

from .source_file import SourceFile
from .translations import Context, Message
from .user import User, UserException


class DesignerSource(SourceFile, User):
    """ Encapsulate a Designer source file. """

    def __init__(self, **kwargs):
        """ Initialise the object. """

        super().__init__(**kwargs)

        # Read the source file.
        self.progress("Reading {0}...".format(self.filename))

        try:
            ui_file = UIFile(self.filename)
        except Exception as e:
            raise UserException(str(e))

        if ui_file.widget is not None:
            context = Context(ui_file.class_name)

            # Get each <string> element.  Note that we don't support the
            # <stringlist> element which seems to provide defaults for the
            # attributes of any child <string> elements.
            for string_el in ui_file.widget.iter('string'):
                if string_el.get('notr', 'false') == 'true':
                    continue

                # This can be None or an empty string depending on the exact
                # XML.
                if not string_el.text:
                    continue

                message = Message(self.filename, 0, string_el.text,
                        string_el.get('comment', ''), False)

                extra_comment = string_el.get('extracomment')
                if extra_comment:
                    message.embedded_comments.extra_comments.append(
                            extra_comment)

                context.messages.append(message)

            if context.messages:
                self.contexts.append(context)



# Form implementation generated from reading ui file 'videosettings.ui'
#
# Created by: PyQt6 UI code generator 6.2.0.dev2107180056
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_VideoSettingsUi(object):
    def setupUi(self, VideoSettingsUi):
        VideoSettingsUi.setObjectName("VideoSettingsUi")
        VideoSettingsUi.resize(686, 499)
        self.gridLayout_3 = QtWidgets.QGridLayout(VideoSettingsUi)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.buttonBox = QtWidgets.QDialogButtonBox(VideoSettingsUi)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout_3.addWidget(self.buttonBox, 4, 1, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(VideoSettingsUi)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.videoResolutionBox = QtWidgets.QComboBox(self.groupBox_2)
        self.videoResolutionBox.setObjectName("videoResolutionBox")
        self.gridLayout_2.addWidget(self.videoResolutionBox, 1, 0, 1, 2)
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 4, 0, 1, 2)
        self.videoFramerateBox = QtWidgets.QComboBox(self.groupBox_2)
        self.videoFramerateBox.setObjectName("videoFramerateBox")
        self.gridLayout_2.addWidget(self.videoFramerateBox, 3, 0, 1, 2)
        self.label_9 = QtWidgets.QLabel(self.groupBox_2)
        self.label_9.setObjectName("label_9")
        self.gridLayout_2.addWidget(self.label_9, 2, 0, 1, 2)
        self.label_8 = QtWidgets.QLabel(self.groupBox_2)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 0, 0, 1, 2)
        self.videoCodecBox = QtWidgets.QComboBox(self.groupBox_2)
        self.videoCodecBox.setObjectName("videoCodecBox")
        self.gridLayout_2.addWidget(self.videoCodecBox, 5, 0, 1, 2)
        self.gridLayout_3.addWidget(self.groupBox_2, 2, 1, 1, 1)
        self.widget = QtWidgets.QWidget(VideoSettingsUi)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget.sizePolicy().hasHeightForWidth())
        self.widget.setSizePolicy(sizePolicy)
        self.widget.setObjectName("widget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.widget)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox_3 = QtWidgets.QGroupBox(self.widget)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.audioCodecBox = QtWidgets.QComboBox(self.groupBox_3)
        self.audioCodecBox.setObjectName("audioCodecBox")
        self.verticalLayout_2.addWidget(self.audioCodecBox)
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_2.addWidget(self.label_5)
        self.audioSampleRateBox = QtWidgets.QSpinBox(self.groupBox_3)
        self.audioSampleRateBox.setObjectName("audioSampleRateBox")
        self.verticalLayout_2.addWidget(self.audioSampleRateBox)
        self.verticalLayout_3.addWidget(self.groupBox_3)
        self.groupBox = QtWidgets.QGroupBox(self.widget)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.verticalLayout.addWidget(self.label_3)
        self.qualitySlider = QtWidgets.QSlider(self.groupBox)
        self.qualitySlider.setMaximum(4)
        self.qualitySlider.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.qualitySlider.setObjectName("qualitySlider")
        self.verticalLayout.addWidget(self.qualitySlider)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.verticalLayout.addWidget(self.label_4)
        self.containerFormatBox = QtWidgets.QComboBox(self.groupBox)
        self.containerFormatBox.setObjectName("containerFormatBox")
        self.verticalLayout.addWidget(self.containerFormatBox)
        self.verticalLayout_3.addWidget(self.groupBox)
        self.gridLayout_3.addWidget(self.widget, 2, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout_3.addItem(spacerItem, 3, 0, 1, 1)

        self.retranslateUi(VideoSettingsUi)
        self.buttonBox.accepted.connect(VideoSettingsUi.accept)
        self.buttonBox.rejected.connect(VideoSettingsUi.reject)
        QtCore.QMetaObject.connectSlotsByName(VideoSettingsUi)

    def retranslateUi(self, VideoSettingsUi):
        _translate = QtCore.QCoreApplication.translate
        VideoSettingsUi.setWindowTitle(_translate("VideoSettingsUi", "Video Settings"))
        self.groupBox_2.setTitle(_translate("VideoSettingsUi", "Video"))
        self.label_6.setText(_translate("VideoSettingsUi", "Video Codec:"))
        self.label_9.setText(_translate("VideoSettingsUi", "Framerate:"))
        self.label_8.setText(_translate("VideoSettingsUi", "Resolution:"))
        self.groupBox_3.setTitle(_translate("VideoSettingsUi", "Audio"))
        self.label_2.setText(_translate("VideoSettingsUi", "Audio Codec:"))
        self.label_5.setText(_translate("VideoSettingsUi", "Sample Rate:"))
        self.label_3.setText(_translate("VideoSettingsUi", "Quality:"))
        self.label_4.setText(_translate("VideoSettingsUi", "File Format:"))



# Form implementation generated from reading ui file 'calculatorform.ui'
#
# Created by: PyQt6 UI code generator 6.1.0.dev2103211315
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_CalculatorForm(object):
    def setupUi(self, CalculatorForm):
        CalculatorForm.setObjectName("CalculatorForm")
        CalculatorForm.resize(400, 300)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy(5), QtWidgets.QSizePolicy.Policy(5))
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(CalculatorForm.sizePolicy().hasHeightForWidth())
        CalculatorForm.setSizePolicy(sizePolicy)
        self.gridlayout = QtWidgets.QGridLayout(CalculatorForm)
        self.gridlayout.setContentsMargins(9, 9, 9, 9)
        self.gridlayout.setSpacing(6)
        self.gridlayout.setObjectName("gridlayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridlayout.addItem(spacerItem, 0, 6, 1, 1)
        self.label_3_2 = QtWidgets.QLabel(CalculatorForm)
        self.label_3_2.setGeometry(QtCore.QRect(169, 9, 20, 52))
        self.label_3_2.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
        self.label_3_2.setObjectName("label_3_2")
        self.gridlayout.addWidget(self.label_3_2, 0, 4, 1, 1)
        self.vboxlayout = QtWidgets.QVBoxLayout()
        self.vboxlayout.setContentsMargins(1, 1, 1, 1)
        self.vboxlayout.setSpacing(6)
        self.vboxlayout.setObjectName("vboxlayout")
        self.label_2_2_2 = QtWidgets.QLabel(CalculatorForm)
        self.label_2_2_2.setGeometry(QtCore.QRect(1, 1, 36, 17))
        self.label_2_2_2.setObjectName("label_2_2_2")
        self.vboxlayout.addWidget(self.label_2_2_2)
        self.outputWidget = QtWidgets.QLabel(CalculatorForm)
        self.outputWidget.setGeometry(QtCore.QRect(1, 24, 36, 27))
        self.outputWidget.setFrameShape(QtWidgets.QFrame.Shape.Box)
        self.outputWidget.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.outputWidget.setAlignment(QtCore.Qt.AlignmentFlag.AlignAbsolute|QtCore.Qt.AlignmentFlag.AlignBottom|QtCore.Qt.AlignmentFlag.AlignCenter|QtCore.Qt.AlignmentFlag.AlignHCenter|QtCore.Qt.AlignmentFlag.AlignHorizontal_Mask|QtCore.Qt.AlignmentFlag.AlignJustify|QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignLeft|QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTop|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter|QtCore.Qt.AlignmentFlag.AlignVertical_Mask)
        self.outputWidget.setObjectName("outputWidget")
        self.vboxlayout.addWidget(self.outputWidget)
        self.gridlayout.addLayout(self.vboxlayout, 0, 5, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridlayout.addItem(spacerItem1, 1, 2, 1, 1)
        self.vboxlayout1 = QtWidgets.QVBoxLayout()
        self.vboxlayout1.setContentsMargins(1, 1, 1, 1)
        self.vboxlayout1.setSpacing(6)
        self.vboxlayout1.setObjectName("vboxlayout1")
        self.label_2 = QtWidgets.QLabel(CalculatorForm)
        self.label_2.setGeometry(QtCore.QRect(1, 1, 46, 19))
        self.label_2.setObjectName("label_2")
        self.vboxlayout1.addWidget(self.label_2)
        self.inputSpinBox2 = QtWidgets.QSpinBox(CalculatorForm)
        self.inputSpinBox2.setGeometry(QtCore.QRect(1, 26, 46, 25))
        self.inputSpinBox2.setObjectName("inputSpinBox2")
        self.vboxlayout1.addWidget(self.inputSpinBox2)
        self.gridlayout.addLayout(self.vboxlayout1, 0, 3, 1, 1)
        self.label_3 = QtWidgets.QLabel(CalculatorForm)
        self.label_3.setGeometry(QtCore.QRect(63, 9, 20, 52))
        self.label_3.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.gridlayout.addWidget(self.label_3, 0, 1, 1, 1)
        self.vboxlayout2 = QtWidgets.QVBoxLayout()
        self.vboxlayout2.setContentsMargins(1, 1, 1, 1)
        self.vboxlayout2.setSpacing(6)
        self.vboxlayout2.setObjectName("vboxlayout2")
        self.label = QtWidgets.QLabel(CalculatorForm)
        self.label.setGeometry(QtCore.QRect(1, 1, 46, 19))
        self.label.setObjectName("label")
        self.vboxlayout2.addWidget(self.label)
        self.inputSpinBox1 = QtWidgets.QSpinBox(CalculatorForm)
        self.inputSpinBox1.setGeometry(QtCore.QRect(1, 26, 46, 25))
        self.inputSpinBox1.setObjectName("inputSpinBox1")
        self.vboxlayout2.addWidget(self.inputSpinBox1)
        self.gridlayout.addLayout(self.vboxlayout2, 0, 0, 1, 1)

        self.retranslateUi(CalculatorForm)
        QtCore.QMetaObject.connectSlotsByName(CalculatorForm)

    def retranslateUi(self, CalculatorForm):
        _translate = QtCore.QCoreApplication.translate
        CalculatorForm.setWindowTitle(_translate("CalculatorForm", "Calculator Form"))
        self.label_3_2.setText(_translate("CalculatorForm", "="))
        self.label_2_2_2.setText(_translate("CalculatorForm", "Output"))
        self.outputWidget.setText(_translate("CalculatorForm", "0"))
        self.label_2.setText(_translate("CalculatorForm", "Input 2"))
        self.label_3.setText(_translate("CalculatorForm", "+"))
        self.label.setText(_translate("CalculatorForm", "Input 1"))



"""
polygonwidgetplugin.py

A polygon widget custom widget plugin for Qt Designer.

Copyright (C) 2006 David Boddie <david@boddie.org.uk>
Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

from PyQt6.QtGui import QIcon, QPixmap
from PyQt6.QtDesigner import QPyDesignerCustomWidgetPlugin

from polygonwidget import PolygonWidget


class PolygonWidgetPlugin(QPyDesignerCustomWidgetPlugin):
    """PolygonWidgetPlugin(QPyDesignerCustomWidgetPlugin)
    
    Provides a Python custom plugin for Qt Designer by implementing the
    QDesignerCustomWidgetPlugin via a PyQt-specific custom plugin class.
    """

    # The __init__() method is only used to set up the plugin and define its
    # initialized variable.
    def __init__(self, parent=None):
    
        super().__init__(parent)

        self.initialized = False

    # The initialize() and isInitialized() methods allow the plugin to set up
    # any required resources, ensuring that this can only happen once for each
    # plugin.
    def initialize(self, core):

        if self.initialized:
            return

        self.initialized = True

    def isInitialized(self):

        return self.initialized

    # This factory method creates new instances of our custom widget with the
    # appropriate parent.
    def createWidget(self, parent):
        return PolygonWidget(parent)

    # This method returns the name of the custom widget class that is provided
    # by this plugin.
    def name(self):
        return "PolygonWidget"

    # Returns the name of the group in Qt Designer's widget box that this
    # widget belongs to.
    def group(self):
        return "PyQt Examples"

    # Returns the icon used to represent the custom widget in Qt Designer's
    # widget box.
    def icon(self):
        return QIcon(_logo_pixmap)

    # Returns a short description of the custom widget for use in a tool tip.
    def toolTip(self):
        return ""

    # Returns a short description of the custom widget for use in a "What's
    # This?" help message for the widget.
    def whatsThis(self):
        return ""

    # Returns True if the custom widget acts as a container for other widgets;
    # otherwise returns False. Note that plugins for custom containers also
    # need to provide an implementation of the QDesignerContainerExtension
    # interface if they need to add custom editing support to Qt Designer.
    def isContainer(self):
        return False

    # Returns an XML description of a custom widget instance that describes
    # default values for its properties. Each custom widget created by this
    # plugin will be configured using this description.
    def domXml(self):
        return '<widget class="PolygonWidget" name="polygonWidget" />\n'

    # Returns the module containing the custom widget class. It may include
    # a module path.
    def includeFile(self):
        return "polygonwidget"


# Define the image used for the icon.
_logo_16x16_xpm = [
"16 16 46 1",
". c #a5a5dc",
"l c #a69fd6",
"k c #a7a5da",
"h c #a7a6dc",
"a c #a7a7de",
"Q c #a8a5da",
"s c #a9a7d7",
"R c #a9a9e0",
"z c #abaad4",
"E c #afafda",
"M c #afafdb",
"K c #b0a8e2",
"o c #b1afe4",
"p c #b2b2d7",
"# c #b2b2ed",
"i c #b39eb6",
"F c #b3b3e1",
"e c #b4b4ef",
"t c #b58bab",
"d c #b6b6f2",
"n c #b798b8",
"P c #b798b9",
"c c #b8b6f2",
"D c #b8b89c",
"m c #b9648d",
"J c #ba84b0",
"A c #bdbdfb",
"f c #bfbffe",
"g c #c06996",
"b c #c0c0ff",
"B c #cbb889",
"L c #cbb989",
"O c #cfcf87",
"I c #d09585",
"w c #d0cf86",
"x c #dede81",
"G c #e8e87c",
"q c #edde7b",
"N c #f1e07b",
"v c #f2e07b",
"H c #f6e57c",
"j c #fb917e",
"u c #ffb580",
"r c #ffda80",
"C c #fffe80",
"y c #ffff80",
".##############a",
"#bbbbbbbbcdbbbbe",
"#bbbbbbbfghbbbbe",
"#bbbbbbbijkbbbbe",
"#blmnobpqrsbbbbe",
"#bbtuvwxyyzbbbbe",
"#bbABCyyyyDEfbbe",
"#bbbFGyyyyyHIJKe",
"#bbbFGyyyyyHIJKe",
"#bbALCyyyyDMfbbe",
"#bbtuNOxyyzbbbbe",
"#blmPobpqrsbbbbe",
"#bbbbbbbijQbbbbe",
"#bbbbbbbfghbbbbe",
"#bbbbbbbbcdbbbbe",
"aeeeeeeeeeeeeeeR"]

_logo_pixmap = QPixmap(_logo_16x16_xpm)



# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


# Map enum member names to fully scoped names.
EnumMap = {
    'Qt::AlignHCenter':         'Qt::AlignmentFlag::AlignHCenter',
    'Qt::AlignJustify':         'Qt::AlignmentFlag::AlignJustify',
    'Qt::AlignLeft':            'Qt::AlignmentFlag::AlignLeft',
    'Qt::AlignRight':           'Qt::AlignmentFlag::AlignRight',

    'Qt::AlignBaseline':        'Qt::AlignmentFlag::AlignBaseline',
    'Qt::AlignBottom':          'Qt::AlignmentFlag::AlignBottom',
    'Qt::AlignTop':             'Qt::AlignmentFlag::AlignTop',
    'Qt::AlignVCenter':         'Qt::AlignmentFlag::AlignVCenter',

    'Qt::AlignAbsolute':        'Qt::AlignmentFlag::AlignAbsolute',
    'Qt::AlignLeading':         'Qt::AlignmentFlag::AlignLeading',
    'Qt::AlignTrailing':        'Qt::AlignmentFlag::AlignTrailing',

    'Qt::AlignCenter':          'Qt::AlignmentFlag::AlignCenter',

    'Qt::AlignHorizontal_Mask': 'Qt::AlignmentFlag::AlignHorizontal_Mask',
    'Qt::AlignVertical_Mask':   'Qt::AlignmentFlag::AlignVertical_Mask',

    'Qt::DownArrow':    'Qt::ArrowType::DownArrow',
    'Qt::LeftArrow':    'Qt::ArrowType::LeftArrow',
    'Qt::NoArrow':      'Qt::ArrowType::NoArrow',
    'Qt::RightArrow':   'Qt::ArrowType::RightArrow',
    'Qt::UpArrow':      'Qt::ArrowType::UpArrow',

    'Qt::Checked':          'Qt::CheckState::Checked',
    'Qt::PartiallyChecked': 'Qt::CheckState::PartiallyChecked',
    'Qt::Unchecked':        'Qt::CheckState::Unchecked',

    'Qt::ActionsContextMenu':   'Qt::ContextMenuPolicy::ActionsContextMenu',
    'Qt::CustomContextMenu':    'Qt::ContextMenuPolicy::CustomContextMenu',
    'Qt::DefaultContextMenu':   'Qt::ContextMenuPolicy::DefaultContextMenu',
    'Qt::NoContextMenu':        'Qt::ContextMenuPolicy::NoContextMenu',
    'Qt::PreventContextMenu':   'Qt::ContextMenuPolicy::PreventContextMenu',

    'Qt::LogicalMoveStyle': 'Qt::CursorMoveStyle::LogicalMoveStyle',
    'Qt::VisualMoveStyle':  'Qt::CursorMoveStyle::VisualMoveStyle',

    'Qt::Monday':       'Qt::DayOfWeek::Monday',
    'Qt::Tuesday':      'Qt::DayOfWeek::Tuesday',
    'Qt::Wednesday':    'Qt::DayOfWeek::Wednesday',
    'Qt::Thursday':     'Qt::DayOfWeek::Thursday',
    'Qt::Friday':       'Qt::DayOfWeek::Friday',
    'Qt::Saturday':     'Qt::DayOfWeek::Saturday',
    'Qt::Sunday':       'Qt::DayOfWeek::Sunday',

    'Qt::AllDockWidgetAreas':   'Qt::DockWidgetArea::AllDockWidgetAreas',
    'Qt::LeftDockWidgetArea':   'Qt::DockWidgetArea::LeftDockWidgetArea',
    'Qt::RightDockWidgetArea':  'Qt::DockWidgetArea::RightDockWidgetArea',
    'Qt::TopDockWidgetArea':    'Qt::DockWidgetArea::TopDockWidgetArea',
    'Qt::BottomDockWidgetArea': 'Qt::DockWidgetArea::BottomDockWidgetArea',
    'Qt::NoDockWidgetArea':     'Qt::DockWidgetArea::NoDockWidgetArea',

    'Qt::ActionMask':       'Qt::DropAction::ActionMask',
    'Qt::CopyAction':       'Qt::DropAction::CopyAction',
    'Qt::IgnoreAction':     'Qt::DropAction::IgnoreAction',
    'Qt::LinkAction':       'Qt::DropAction::LinkAction',
    'Qt::MoveAction':       'Qt::DropAction::MoveAction',
    'Qt::TargetMoveAction': 'Qt::DropAction::TargetMoveAction',

    'Qt::ClickFocus':   'Qt::FocusPolicy::ClickFocus',
    'Qt::NoFocus':      'Qt::FocusPolicy::NoFocus',
    'Qt::TabFocus':     'Qt::FocusPolicy::TabFocus',
    'Qt::StrongFocus':  'Qt::FocusPolicy::StrongFocus',
    'Qt::WheelFocus':   'Qt::FocusPolicy::WheelFocus',

    'Qt::ImhDate':                  'Qt::InputMethodHint::ImhDate',
    'Qt::ImhDialableCharactersOnly':    'Qt::InputMethodHint::ImhDialableCharactersOnly',
    'Qt::ImhDigitsOnly':            'Qt::InputMethodHint::ImhDigitsOnly',
    'Qt::ImhEmailCharactersOnly':   'Qt::InputMethodHint::ImhEmailCharactersOnly',
    'Qt::ImhExclusiveInputMask':    'Qt::InputMethodHint::ImhExclusiveInputMask',
    'Qt::ImhFormattedNumbersOnly':  'Qt::InputMethodHint::ImhFormattedNumbersOnly',
    'Qt::ImhHiddenText':            'Qt::InputMethodHint::ImhHiddenText',
    'Qt::ImhLatinOnly':             'Qt::InputMethodHint::ImhLatinOnly',
    'Qt::ImhLowercaseOnly':         'Qt::InputMethodHint::ImhLowercaseOnly',
    'Qt::ImhMultiLine':             'Qt::InputMethodHint::ImhMultiLine',
    'Qt::ImhNoAutoUppercase':       'Qt::InputMethodHint::ImhNoAutoUppercase',
    'Qt::ImhNoEditMenu':            'Qt::InputMethodHint::ImhNoEditMenu',
    'Qt::ImhNoPredictiveText':      'Qt::InputMethodHint::ImhNoPredictiveText',
    'Qt::ImhNoTextHandles':         'Qt::InputMethodHint::ImhNoTextHandles',
    'Qt::ImhNone':                  'Qt::InputMethodHint::ImhNone',
    'Qt::ImhPreferLatin':           'Qt::InputMethodHint::ImhPreferLatin',
    'Qt::ImhPreferLowercase':       'Qt::InputMethodHint::ImhPreferLowercase',
    'Qt::ImhPreferNumbers':         'Qt::InputMethodHint::ImhPreferNumbers',
    'Qt::ImhPreferUppercase':       'Qt::InputMethodHint::ImhPreferUppercase',
    'Qt::ImhSensitiveData':         'Qt::InputMethodHint::ImhSensitiveData',
    'Qt::ImhTime':                  'Qt::InputMethodHint::ImhTime',
    'Qt::ImhUppercaseOnly':         'Qt::InputMethodHint::ImhUppercaseOnly',
    'Qt::ImhUrlCharactersOnly':     'Qt::InputMethodHint::ImhUrlCharactersOnly',

    'Qt::ItemIsAutoTristate':   'Qt::ItemFlag::ItemIsAutoTristate',
    'Qt::ItemIsDragEnabled':    'Qt::ItemFlag::ItemIsDragEnabled',
    'Qt::ItemIsDropEnabled':    'Qt::ItemFlag::ItemIsDropEnabled',
    'Qt::ItemIsEditable':       'Qt::ItemFlag::ItemIsEditable',
    'Qt::ItemIsEnabled':        'Qt::ItemFlag::ItemIsEnabled',
    'Qt::ItemIsSelectable':     'Qt::ItemFlag::ItemIsSelectable',
    'Qt::ItemIsUserCheckable':  'Qt::ItemFlag::ItemIsUserCheckable',
    'Qt::ItemIsUserTristate':   'Qt::ItemFlag::ItemIsUserTristate',
    'Qt::ItemNeverHasChildren': 'Qt::ItemFlag::ItemNeverHasChildren',
    'Qt::NoItemFlags':          'Qt::ItemFlag::NoItemFlags',

    'Qt::ContainsItemBoundingRect':     'Qt::ItemSelectionMode::ContainsItemBoundingRect',
    'Qt::ContainsItemShape':            'Qt::ItemSelectionMode::ContainsItemShape',
    'Qt::IntersectsItemBoundingRect':   'Qt::ItemSelectionMode::IntersectsItemBoundingRect',
    'Qt::IntersectsItemShape':          'Qt::ItemSelectionMode::IntersectsItemShape',

    'Qt::LayoutDirectionAuto':  'Qt::LayoutDirection::LayoutDirectionAuto',
    'Qt::LeftToRight':          'Qt::LayoutDirection::LeftToRight',
    'Qt::RightToLeft':          'Qt::LayoutDirection::RightToLeft',

    'Qt::Horizontal':   'Qt::Orientation::Horizontal',
    'Qt::Vertical':     'Qt::Orientation::Vertical',

    'Qt::CustomDashLine':   'Qt::PenStyle::CustomDashLine',
    'Qt::DashDotDotLine':   'Qt::PenStyle::DashDotDotLine',
    'Qt::DashDotLine':      'Qt::PenStyle::DashDotLine',
    'Qt::DashLine':         'Qt::PenStyle::DashLine',
    'Qt::DotLine':          'Qt::PenStyle::DotLine',
    'Qt::NoPen':            'Qt::PenStyle::NoPen',
    'Qt::SolidLine':        'Qt::PenStyle::SolidLine',

    'Qt::ScrollBarAlwaysOff':   'Qt::ScrollBarPolicy::ScrollBarAlwaysOff',
    'Qt::ScrollBarAlwaysOn':    'Qt::ScrollBarPolicy::ScrollBarAlwaysOn',
    'Qt::ScrollBarAsNeeded':    'Qt::ScrollBarPolicy::ScrollBarAsNeeded',

    'Qt::ApplicationShortcut':          'Qt::ShortcutContext::ApplicationShortcut',
    'Qt::WidgetShortcut':               'Qt::ShortcutContext::WidgetShortcut',
    'Qt::WidgetWithChildrenShortcut':   'Qt::ShortcutContext::WidgetWithChildrenShortcut',
    'Qt::WindowShortcut':               'Qt::ShortcutContext::WindowShortcut',

    'Qt::ElideLeft':    'Qt::TextElideMode::ElideLeft',
    'Qt::ElideRight':   'Qt::TextElideMode::ElideRight',
    'Qt::ElideMiddle':  'Qt::TextElideMode::ElideMiddle',
    'Qt::ElideNone':    'Qt::TextElideMode::ElideNone',

    'Qt::NoTextInteraction':            'Qt::TextInteractionFlag::NoTextInteraction',
    'Qt::TextSelectableByMouse':        'Qt::TextInteractionFlag::TextSelectableByMouse',
    'Qt::TextSelectableByKeyboard':     'Qt::TextInteractionFlag::TextSelectableByKeyboard',
    'Qt::LinksAccessibleByMouse':       'Qt::TextInteractionFlag::LinksAccessibleByMouse',
    'Qt::LinksAccessibleByKeyboard':    'Qt::TextInteractionFlag::LinksAccessibleByKeyboard',
    'Qt::TextEditable':                 'Qt::TextInteractionFlag::TextEditable',
    'Qt::TextEditorInteraction':        'Qt::TextInteractionFlag::TextEditorInteraction',
    'Qt::TextBrowserInteraction':       'Qt::TextInteractionFlag::TextBrowserInteraction',

    'Qt::AutoText':     'Qt::TextFormat::AutoText',
    'Qt::MarkdownText': 'Qt::TextFormat::MarkdownText',
    'Qt::PlainText':    'Qt::TextFormat::PlainText',
    'Qt::RichText':     'Qt::TextFormat::RichText',

    'Qt::LocalTime':        'Qt::TimeSpec::LocalTime',
    'Qt::OffsetFromUTC':    'Qt::TimeSpec::OffsetFromUTC',
    'Qt::TimeZone':         'Qt::TimeSpec::TimeZone',
    'Qt::UTC':              'Qt::TimeSpec::UTC',

    'Qt::LeftToolBarArea':      'Qt::ToolBarArea::LeftToolBarArea',
    'Qt::RightToolBarArea':     'Qt::ToolBarArea::RightToolBarArea',
    'Qt::TopToolBarArea':       'Qt::ToolBarArea::TopToolBarArea',
    'Qt::BottomToolBarArea':    'Qt::ToolBarArea::BottomToolBarArea',
    'Qt::AllToolBarAreas':      'Qt::ToolBarArea::AllToolBarAreas',
    'Qt::NoToolBarArea':        'Qt::ToolBarArea::NoToolBarArea',

    'Qt::ToolButtonFollowStyle':    'Qt::ToolButtonStyle::ToolButtonFollowStyle',
    'Qt::ToolButtonIconOnly':       'Qt::ToolButtonStyle::ToolButtonIconOnly',
    'Qt::ToolButtonTextBesideIcon': 'Qt::ToolButtonStyle::ToolButtonTextBesideIcon',
    'Qt::ToolButtonTextOnly':       'Qt::ToolButtonStyle::ToolButtonTextOnly',
    'Qt::ToolButtonTextUnderIcon':  'Qt::ToolButtonStyle::ToolButtonTextUnderIcon',

    'Qt::ApplicationModal': 'Qt::WindowModality::ApplicationModal',
    'Qt::NonModal':         'Qt::WindowModality::NonModal',
    'Qt::WindowModal':      'Qt::WindowModality::WindowModal',

    'QAbstractItemView::NoDragDrop':    'QAbstractItemView::DragDropMode::NoDragDrop',
    'QAbstractItemView::DragOnly':      'QAbstractItemView::DragDropMode::DragOnly',
    'QAbstractItemView::DropOnly':      'QAbstractItemView::DragDropMode::DropOnly',
    'QAbstractItemView::DragDrop':      'QAbstractItemView::DragDropMode::DragDrop',
    'QAbstractItemView::InternalMove':  'QAbstractItemView::DragDropMode::InternalMove',

    'QAbstractItemView::NoEditTriggers':    'QAbstractItemView::EditTrigger::NoEditTriggers',
    'QAbstractItemView::CurrentChanged':    'QAbstractItemView::EditTrigger::CurrentChanged',
    'QAbstractItemView::DoubleClicked':     'QAbstractItemView::EditTrigger::DoubleClicked',
    'QAbstractItemView::SelectedClicked':   'QAbstractItemView::EditTrigger::SelectedClicked',
    'QAbstractItemView::EditKeyPressed':    'QAbstractItemView::EditTrigger::EditKeyPressed',
    'QAbstractItemView::AnyKeyPressed':     'QAbstractItemView::EditTrigger::AnyKeyPressed',
    'QAbstractItemView::AllEditTriggers':   'QAbstractItemView::EditTrigger::AllEditTriggers',

    'QAbstractItemView::ScrollPerItem':     'QAbstractItemView::ScrollMode::ScrollPerItem',
    'QAbstractItemView::ScrollPerPixel':    'QAbstractItemView::ScrollMode::ScrollPerPixel',

    'QAbstractItemView::SelectColumns': 'QAbstractItemView::SelectionBehavior::SelectColumns',
    'QAbstractItemView::SelectItems':   'QAbstractItemView::SelectionBehavior::SelectItems',
    'QAbstractItemView::SelectRows':    'QAbstractItemView::SelectionBehavior::SelectRows',

    'QAbstractItemView::NoSelection':           'QAbstractItemView::SelectionMode::NoSelection',
    'QAbstractItemView::SingleSelection':       'QAbstractItemView::SelectionMode::SingleSelection',
    'QAbstractItemView::MultiSelection':        'QAbstractItemView::SelectionMode::MultiSelection',
    'QAbstractItemView::ExtendedSelection':     'QAbstractItemView::SelectionMode::ExtendedSelection',
    'QAbstractItemView::ContiguousSelection':   'QAbstractItemView::SelectionMode::ContiguousSelection',

    'QAbstractScrollArea::AdjustIgnored':               'QAbstractScrollArea::SizeAdjustPolicy::AdjustIgnored',
    'QAbstractScrollArea::AdjustToContents':            'QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents',
    'QAbstractScrollArea::AdjustToContentsOnFirstShow': 'QAbstractScrollArea::SizeAdjustPolicy::AdjustToContentsOnFirstShow',

    'QAbstractSpinBox::NoButtons':      'QAbstractSpinBox::ButtonSymbols::NoButtons',
    'QAbstractSpinBox::PlusMinus':      'QAbstractSpinBox::ButtonSymbols::PlusMinus',
    'QAbstractSpinBox::UpDownArrows':   'QAbstractSpinBox::ButtonSymbols::UpDownArrows',

    'QAbstractSpinBox::CorrectToNearestValue': 'QAbstractSpinBox::CorrectionMode::CorrectToNearestValue',
    'QAbstractSpinBox::CorrectToPreviousValue': 'QAbstractSpinBox::CorrectionMode::CorrectToPreviousValue',

    'QAbstractSpinBox::AdaptiveDecimalStepType':    'QAbstractSpinBox::StepType::AdaptiveDecimalStepType',
    'QAbstractSpinBox::DefaultStepType':            'QAbstractSpinBox::StepType::DefaultStepType',

    'QAction::NoRole':                  'QAction::MenuRole::NoRole',
    'QAction::TextHeuristicRole':       'QAction::MenuRole::TextHeuristicRole',
    'QAction::ApplicationSpecificRole': 'QAction::MenuRole::ApplicationSpecificRole',
    'QAction::AboutQtRole':             'QAction::MenuRole::AboutQtRole',
    'QAction::AboutRole':               'QAction::MenuRole::AboutRole',
    'QAction::PreferencesRole':         'QAction::MenuRole::PreferencesRole',
    'QAction::QuitRole':                'QAction::MenuRole::QuitRole',

    'QCalendarWidget::LongDayNames':            'QCalendarWidget::HorizontalHeaderFormat::LongDayNames',
    'QCalendarWidget::NoHorizontalHeader':      'QCalendarWidget::HorizontalHeaderFormat::NoHorizontalHeader',
    'QCalendarWidget::ShortDayNames':           'QCalendarWidget::HorizontalHeaderFormat::ShortDayNames',
    'QCalendarWidget::SingleLetterDayNames':    'QCalendarWidget::HorizontalHeaderFormat::SingleLetterDayNames',

    'QCalendarWidget::NoSelection':     'QCalendarWidget::SelectionMode::NoSelection',
    'QCalendarWidget::SingleSelection': 'QCalendarWidget::SelectionMode::SingleSelection',

    'QCalendarWidget::ISOWeekNumbers':      'QCalendarWidget::VerticalHeaderFormat::ISOWeekNumbers',
    'QCalendarWidget::NoVerticalHeader':    'QCalendarWidget::VerticalHeaderFormat::NoVerticalHeader',

    'QComboBox::InsertAfterCurrent':    'QComboBox::InsertPolicy::InsertAfterCurrent',
    'QComboBox::InsertAlphabetically':  'QComboBox::InsertPolicy::InsertAlphabetically',
    'QComboBox::InsertAtBottom':        'QComboBox::InsertPolicy::InsertAtBottom',
    'QComboBox::InsertAtCurrent':       'QComboBox::InsertPolicy::InsertAtCurrent',
    'QComboBox::InsertAtTop':           'QComboBox::InsertPolicy::InsertAtTop',
    'QComboBox::InsertBeforeCurrent':   'QComboBox::InsertPolicy::InsertBeforeCurrent',
    'QComboBox::NoInsert':              'QComboBox::InsertPolicy::NoInsert',

    'QComboBox::AdjustToContents':                      'QComboBox::SizeAdjustPolicy::AdjustToContents',
    'QComboBox::AdjustToContentsOnFirstShow':           'QComboBox::SizeAdjustPolicy::AdjustToContentsOnFirstShow',
    'QComboBox::AdjustToMinimumContentsLengthWithIcon': 'QComboBox::SizeAdjustPolicy::AdjustToMinimumContentsLengthWithIcon',

    'QDateTimeEdit::NoSection':             'QDateTimeEdit::Section::NoSection',
    'QDateTimeEdit::AmPmSection':           'QDateTimeEdit::Section::AmPmSection',
    'QDateTimeEdit::MSecSection':           'QDateTimeEdit::Section::MSecSection',
    'QDateTimeEdit::SecondSection':         'QDateTimeEdit::Section::SecondSection',
    'QDateTimeEdit::MinuteSection':         'QDateTimeEdit::Section::MinuteSection',
    'QDateTimeEdit::HourSection':           'QDateTimeEdit::Section::HourSection',
    'QDateTimeEdit::DaySection':            'QDateTimeEdit::Section::DaySection',
    'QDateTimeEdit::MonthSection':          'QDateTimeEdit::Section::MonthSection',
    'QDateTimeEdit::YearSection':           'QDateTimeEdit::Section::YearSection',

    'QDialogButtonBox::NoButton':           'QDialogButtonBox::StandardButton::NoButton',
    'QDialogButtonBox::Ok':                 'QDialogButtonBox::StandardButton::Ok',
    'QDialogButtonBox::Save':               'QDialogButtonBox::StandardButton::Save',
    'QDialogButtonBox::SaveAll':            'QDialogButtonBox::StandardButton::SaveAll',
    'QDialogButtonBox::Open':               'QDialogButtonBox::StandardButton::Open',
    'QDialogButtonBox::Yes':                'QDialogButtonBox::StandardButton::Yes',
    'QDialogButtonBox::YesToAll':           'QDialogButtonBox::StandardButton::YesToAll',
    'QDialogButtonBox::No':                 'QDialogButtonBox::StandardButton::No',
    'QDialogButtonBox::NoToAll':            'QDialogButtonBox::StandardButton::NoToAll',
    'QDialogButtonBox::Abort':              'QDialogButtonBox::StandardButton::Abort',
    'QDialogButtonBox::Retry':              'QDialogButtonBox::StandardButton::Retry',
    'QDialogButtonBox::Ignore':             'QDialogButtonBox::StandardButton::Ignore',
    'QDialogButtonBox::Close':              'QDialogButtonBox::StandardButton::Close',
    'QDialogButtonBox::Cancel':             'QDialogButtonBox::StandardButton::Cancel',
    'QDialogButtonBox::Discard':            'QDialogButtonBox::StandardButton::Discard',
    'QDialogButtonBox::Help':               'QDialogButtonBox::StandardButton::Help',
    'QDialogButtonBox::Apply':              'QDialogButtonBox::StandardButton::Apply',
    'QDialogButtonBox::Reset':              'QDialogButtonBox::StandardButton::Reset',
    'QDialogButtonBox::RestoreDefaults':    'QDialogButtonBox::StandardButton::RestoreDefaults',

    'QDockWidget::DockWidgetClosable':          'QDockWidget::DockWidgetFeature::DockWidgetClosable',
    'QDockWidget::DockWidgetFloatable':         'QDockWidget::DockWidgetFeature::DockWidgetFloatable',
    'QDockWidget::DockWidgetMovable':           'QDockWidget::DockWidgetFeature::DockWidgetMovable',
    'QDockWidget::DockWidgetVerticalTitleBar':  'QDockWidget::DockWidgetFeature::DockWidgetVerticalTitleBar',
    'QDockWidget::NoDockWidgetFeatures':        'QDockWidget::DockWidgetFeature::NoDockWidgetFeatures',

    'QFontComboBox::AllFonts':          'QFontComboBox::FontFilter::AllFonts',
    'QFontComboBox::MonospacedFonts':   'QFontComboBox::FontFilter::MonospacedFonts',
    'QFontComboBox::NonScalableFonts':  'QFontComboBox::FontFilter::NonScalableFonts',
    'QFontComboBox::ProportionalFonts': 'QFontComboBox::FontFilter::ProportionalFonts',
    'QFontComboBox::ScalableFonts':     'QFontComboBox::FontFilter::ScalableFonts',

    'QFontDatabase::Any':                   'QFontDatabase::WritingSystem::Any',
    'QFontDatabase::Latin':                 'QFontDatabase::WritingSystem::Latin',
    'QFontDatabase::Greek':                 'QFontDatabase::WritingSystem::Greek',
    'QFontDatabase::Cyrillic':              'QFontDatabase::WritingSystem::Cyrillic',
    'QFontDatabase::Armenian':              'QFontDatabase::WritingSystem::Armenian',
    'QFontDatabase::Hebrew':                'QFontDatabase::WritingSystem::Hebrew',
    'QFontDatabase::Arabic':                'QFontDatabase::WritingSystem::Arabic',
    'QFontDatabase::Syriac':                'QFontDatabase::WritingSystem::Syriac',
    'QFontDatabase::Thaana':                'QFontDatabase::WritingSystem::Thaana',
    'QFontDatabase::Devanagari':            'QFontDatabase::WritingSystem::Devanagari',
    'QFontDatabase::Bengali':               'QFontDatabase::WritingSystem::Bengali',
    'QFontDatabase::Gurmukhi':              'QFontDatabase::WritingSystem::Gurmukhi',
    'QFontDatabase::Gujarati':              'QFontDatabase::WritingSystem::Gujarati',
    'QFontDatabase::Oriya':                 'QFontDatabase::WritingSystem::Oriya',
    'QFontDatabase::Tamil':                 'QFontDatabase::WritingSystem::Tamil',
    'QFontDatabase::Telugu':                'QFontDatabase::WritingSystem::Telugu',
    'QFontDatabase::Kannada':               'QFontDatabase::WritingSystem::Kannada',
    'QFontDatabase::Malayalam':             'QFontDatabase::WritingSystem::Malayalam',
    'QFontDatabase::Sinhala':               'QFontDatabase::WritingSystem::Sinhala',
    'QFontDatabase::Thai':                  'QFontDatabase::WritingSystem::Thai',
    'QFontDatabase::Lao':                   'QFontDatabase::WritingSystem::Lao',
    'QFontDatabase::Tibetan':               'QFontDatabase::WritingSystem::Tibetan',
    'QFontDatabase::Myanmar':               'QFontDatabase::WritingSystem::Myanmar',
    'QFontDatabase::Georgian':              'QFontDatabase::WritingSystem::Georgian',
    'QFontDatabase::Khmer':                 'QFontDatabase::WritingSystem::Khmer',
    'QFontDatabase::SimplifiedChinese':     'QFontDatabase::WritingSystem::SimplifiedChinese',
    'QFontDatabase::TraditionalChinese':    'QFontDatabase::WritingSystem::TraditionalChinese',
    'QFontDatabase::Japanese':              'QFontDatabase::WritingSystem::Japanese',
    'QFontDatabase::Korean':                'QFontDatabase::WritingSystem::Korean',
    'QFontDatabase::Vietnamese':            'QFontDatabase::WritingSystem::Vietnamese',
    'QFontDatabase::Other':                 'QFontDatabase::WritingSystem::Other',
    'QFontDatabase::Symbol':                'QFontDatabase::WritingSystem::Symbol',
    'QFontDatabase::Ogham':                 'QFontDatabase::WritingSystem::Ogham',
    'QFontDatabase::Runic':                 'QFontDatabase::WritingSystem::Runic',
    'QFontDatabase::Nko':                   'QFontDatabase::WritingSystem::Nko',

    'QFormLayout::AllNonFixedFieldsGrow':   'QFormLayout::FieldGrowthPolicy::AllNonFixedFieldsGrow',
    'QFormLayout::ExpandingFieldsGrow':     'QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow',
    'QFormLayout::FieldsStayAtSizeHint':    'QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint',

    'QFormLayout::DontWrapRows':    'QFormLayout::RowWrapPolicy::DontWrapRows',
    'QFormLayout::WrapLongRows':    'QFormLayout::RowWrapPolicy::WrapLongRows',
    'QFormLayout::WrapAllRows':     'QFormLayout::RowWrapPolicy::WrapAllRows',

    'QFrame::Box':          'QFrame::Shape::Box',
    'QFrame::HLine':        'QFrame::Shape::HLine',
    'QFrame::NoFrame':      'QFrame::Shape::NoFrame',
    'QFrame::Panel':        'QFrame::Shape::Panel',
    'QFrame::StyledPanel':  'QFrame::Shape::StyledPanel',
    'QFrame::VLine':        'QFrame::Shape::VLine',
    'QFrame::WinPanel':     'QFrame::Shape::WinPanel',

    'QFrame::Plain':    'QFrame::Shadow::Plain',
    'QFrame::Raised':   'QFrame::Shadow::Raised',
    'QFrame::Sunken':   'QFrame::Shadow::Sunken',

    'QGraphicsView::CacheNone':         'QGraphicsView::CacheMode::CacheNone',
    'QGraphicsView::CacheBackground':   'QGraphicsView::CacheMode::CacheBackground',

    'QGraphicsView::DontAdjustForAntialiasing': 'QGraphicsView::OptimizationFlags::DontAdjustForAntialiasing',
    'QGraphicsView::DontSavePainterState':      'QGraphicsView::OptimizationFlags::DontSavePainterState',

    'QGraphicsView::NoAnchor':          'QGraphicsView::ViewportAnchor::NoAnchor',
    'QGraphicsView::AnchorViewCenter':  'QGraphicsView::ViewportAnchor::AnchorViewCenter',
    'QGraphicsView::AnchorUnderMouse':  'QGraphicsView::ViewportAnchor::AnchorUnderMouse',

    'QGraphicsView::BoundingRectViewportUpdate':    'QGraphicsView::ViewportUpdateMode::BoundingRectViewportUpdate',
    'QGraphicsView::FullViewportUpdate':            'QGraphicsView::ViewportUpdateMode::FullViewportUpdate',
    'QGraphicsView::MinimalViewportUpdate':         'QGraphicsView::ViewportUpdateMode::MinimalViewportUpdate',
    'QGraphicsView::NoViewportUpdate':              'QGraphicsView::ViewportUpdateMode::NoViewportUpdate',
    'QGraphicsView::SmartViewportUpdate':           'QGraphicsView::ViewportUpdateMode::SmartViewportUpdate',

    'QLayout::SetDefaultConstraint':    'QLayout::SizeConstraint::SetDefaultConstraint',
    'QLayout::SetFixedSize':            'QLayout::SizeConstraint::SetFixedSize',
    'QLayout::SetMaximumSize':          'QLayout::SizeConstraint::SetMaximumSize',
    'QLayout::SetMinAndMaxSize':        'QLayout::SizeConstraint::SetMinAndMaxSize',
    'QLayout::SetMinimumSize':          'QLayout::SizeConstraint::SetMinimumSize',
    'QLayout::SetNoConstraint':         'QLayout::SizeConstraint::SetNoConstraint',

    'QLCDNumber::Bin':  'QLCDNumber::Mode::Bin',
    'QLCDNumber::Dec':  'QLCDNumber::Mode::Dec',
    'QLCDNumber::Hex':  'QLCDNumber::Mode::Hex',
    'QLCDNumber::Oct':  'QLCDNumber::Mode::Oct',

    'QLCDNumber::Filled':   'QLCDNumber::SegmentStyle::Filled',
    'QLCDNumber::Flat':     'QLCDNumber::SegmentStyle::Flat',
    'QLCDNumber::Outline':  'QLCDNumber::SegmentStyle::Outline',

    'QLineEdit::NoEcho':                'QLineEdit::EchoMode::NoEcho',
    'QLineEdit::Normal':                'QLineEdit::EchoMode::Normal',
    'QLineEdit::Password':              'QLineEdit::EchoMode::Password',
    'QLineEdit::PasswordEchoOnEdit':    'QLineEdit::EchoMode::PasswordEchoOnEdit',

    'QListView::LeftToRight':   'QListView::Flow::LeftToRight',
    'QListView::TopToBottom':   'QListView::Flow::TopToBottom',

    'QListView::Batched':       'QListView::LayoutMode::Batched',
    'QListView::SinglePass':    'QListView::LayoutMode::SinglePass',

    'QListView::Free':      'QListView::Movement::Free',
    'QListView::Snap':      'QListView::Movement::Snap',
    'QListView::Static':    'QListView::Movement::Static',

    'QListView::Adjust':    'QListView::ResizeMode::Adjust',
    'QListView::Fixed':     'QListView::ResizeMode::Fixed',

    'QListView::IconMode':  'QListView::ViewMode::IconMode',
    'QListView::ListMode':  'QListView::ViewMode::ListMode',

    'QMdiArea::SubWindowView':  'QMdiArea::ViewMode::SubWindowView',
    'QMdiArea::TabbedView':     'QMdiArea::ViewMode::TabbedView',

    'QMdiArea::ActivationHistoryOrder': 'QMdiArea::WindowOrder::ActivationHistoryOrder',
    'QMdiArea::CreationOrder':          'QMdiArea::WindowOrder::CreationOrder',
    'QMdiArea::StackingOrder':          'QMdiArea::WindowOrder::StackingOrder',

    'QPainter::Antialiasing':           'QPainter::RenderHint::Antialiasing',
    'QPainter::LosslessImageRendering': 'QPainter::RenderHint::LosslessImageRendering',
    'QPainter::SmoothPixmapTransform':  'QPainter::RenderHint::SmoothPixmapTransform',
    'QPainter::TextAntialiasing':       'QPainter::RenderHint::TextAntialiasing',

    'QPlainTextEdit::NoWrap':       'QPlainTextEdit::LineWrapMode::NoWrap',
    'QPlainTextEdit::WidgetWidth':  'QPlainTextEdit::LineWrapMode::WidgetWidth',

    'QProgressBar::BottomToTop':  'QProgressBar::Direction::BottomToTop',
    'QProgressBar::TopToBottom':  'QProgressBar::Direction::TopToBottom',

    'QQuickWidget::SizeRootObjectToView':   'QQuickWidget::ResizeMode::SizeRootObjectToView',
    'QQuickWidget::SizeViewToRootObject':   'QQuickWidget::ResizeMode::SizeViewToRootObject',

    'QSizePolicy::Fixed':               'QSizePolicy::Policy::Fixed',
    'QSizePolicy::Minimum':             'QSizePolicy::Policy::Minimum',
    'QSizePolicy::Maximum':             'QSizePolicy::Policy::Maximum',
    'QSizePolicy::Preferred':           'QSizePolicy::Policy::Preferred',
    'QSizePolicy::MinimumExpanding':    'QSizePolicy::Policy::MinimumExpanding',
    'QSizePolicy::Expanding':           'QSizePolicy::Policy::Expanding',
    'QSizePolicy::Ignored':             'QSizePolicy::Policy::Ignored',

    'QSlider::NoTicks':         'QSlider::TickPosition::NoTicks',
    'QSlider::TicksAbove':      'QSlider::TickPosition::TicksAbove',
    'QSlider::TicksBelow':      'QSlider::TickPosition::TicksBelow',
    'QSlider::TicksBothSides':  'QSlider::TickPosition::TicksBothSides',
    'QSlider::TicksLeft':       'QSlider::TickPosition::TicksLeft',
    'QSlider::TicksRight':      'QSlider::TickPosition::TicksRight',

    'QTabWidget::North':    'QTabWidget::TabPosition::North',
    'QTabWidget::South':    'QTabWidget::TabPosition::South',
    'QTabWidget::West':     'QTabWidget::TabPosition::West',
    'QTabWidget::East':     'QTabWidget::TabPosition::East',

    'QTabWidget::Rounded':      'QTabWidget::TabShape::Rounded',
    'QTabWidget::Triangular':   'QTabWidget::TabShape::Triangular',

    'QTextEdit::AutoAll':           'QTextEdit::AutoFormattingFlag::AutoAll',
    'QTextEdit::AutoBulletList':    'QTextEdit::AutoFormattingFlag::AutoBulletList',
    'QTextEdit::AutoNone':          'QTextEdit::AutoFormattingFlag::AutoNone',

    'QTextEdit::FixedColumnWidth':  'QTextEdit::LineWrapMode::FixedColumnWidth',
    'QTextEdit::FixedPixelWidth':   'QTextEdit::LineWrapMode::FixedPixelWidth',
    'QTextEdit::NoWrap':            'QTextEdit::LineWrapMode::NoWrap',
    'QTextEdit::WidgetWidth':       'QTextEdit::LineWrapMode::WidgetWidth',

    'QToolButton::DelayedPopup':    'QToolButton::ToolButtonPopupMode::DelayedPopup',
    'QToolButton::InstantPopup':    'QToolButton::ToolButtonPopupMode::InstantPopup',
    'QToolButton::MenuButtonPopup': 'QToolButton::ToolButtonPopupMode::MenuButtonPopup',

    'QWizard::CancelButtonOnLeft':              'QWizard::WizardOption::CancelButtonOnLeft',
    'QWizard::DisabledBackButtonOnLastPage':    'QWizard::WizardOption::DisabledBackButtonOnLastPage',
    'QWizard::ExtendedWatermarkPixmap':         'QWizard::WizardOption::ExtendedWatermarkPixmap',
    'QWizard::HaveCustomButton1':               'QWizard::WizardOption::HaveCustomButton1',
    'QWizard::HaveCustomButton2':               'QWizard::WizardOption::HaveCustomButton2',
    'QWizard::HaveCustomButton3':               'QWizard::WizardOption::HaveCustomButton3',
    'QWizard::HaveFinishButtonOnEarlyPages':    'QWizard::WizardOption::HaveFinishButtonOnEarlyPages',
    'QWizard::HaveHelpButton':                  'QWizard::WizardOption::HaveHelpButton',
    'QWizard::HaveNextButtonOnLastPage':        'QWizard::WizardOption::HaveNextButtonOnLastPage',
    'QWizard::HelpButtonOnRight':               'QWizard::WizardOption::HelpButtonOnRight',
    'QWizard::IgnoreSubTitles':                 'QWizard::WizardOption::IgnoreSubTitles',
    'QWizard::IndependentPages':                'QWizard::WizardOption::IndependentPages',
    'QWizard::NoBackButtonOnLastPage':          'QWizard::WizardOption::NoBackButtonOnLastPage',
    'QWizard::NoBackButtonOnStartPage':         'QWizard::WizardOption::NoBackButtonOnStartPage',
    'QWizard::NoCancelButton':                  'QWizard::WizardOption::NoCancelButton',
    'QWizard::NoCancelButtonOnLastPage':        'QWizard::WizardOption::NoCancelButtonOnLastPage',
    'QWizard::NoDefaultButton':                 'QWizard::WizardOption::NoDefaultButton',

    'QWizard::AeroStyle':       'QWizard::WizardStyle::AeroStyle',
    'QWizard::ClassicStyle':    'QWizard::WizardStyle::ClassicStyle',
    'QWizard::MacStyle':        'QWizard::WizardStyle::MacStyle',
    'QWizard::ModernStyle':     'QWizard::WizardStyle::ModernStyle',
}



# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from xml.etree import ElementTree


class UIFile:
    """ Encapsulate a Designer .ui file. """

    def __init__(self, ui_file):
        """ Initialise the .ui file. """

        # Get the name of the .ui file allowing it to be a file object.
        if hasattr(ui_file, 'read'):
            self._ui_file = getattr(ui_file, 'name', "unknown")
        else:
            self._ui_file = ui_file

        try:
            document = ElementTree.parse(ui_file)
        except Exception as e:
            self._raise_exception("invalid Qt Designer file", detail=str(e))

        # Perform some sanity checks.
        root = document.getroot()

        if root.tag != 'ui':
            self._raise_exception("not created by Qt Designer")

        version = root.get('version')
        if version is None:
            self._raise_exception("missing version number")

        if version != '4.0':
            self._raise_exception("only Qt Designer files v4.0 are supported")

        # Extract the top-level elements.
        self.button_groups = None
        self.connections = None
        self.custom_widgets = None
        self.layout_default = None
        self.tab_stops = None
        self.widget = None

        self.class_name = None

        for el in root:
            if el.tag == 'class':
                self.class_name = el.text
            elif el.tag == 'buttongroups':
                self.button_groups = el
            elif el.tag == 'connections':
                self.connections = el
            elif el.tag == 'customwidgets':
                self.custom_widgets = el
            elif el.tag == 'layoutdefault':
                self.layout_default = el
            elif el.tag == 'tabstops':
                self.tab_stops = el
            elif el.tag == 'widget':
                self.widget = el

        # The <class> element was optional in legacy versions of the schema.
        if not self.class_name:
            if self.widget is not None:
                self.class_name = self.widget.get('name')

            if not self.class_name:
                self._raise_exception(
                        "unable to determine the name of the UI class")

    def _raise_exception(self, message, detail=''):
        """ Raise a UIFileException. """

        from .exceptions import UIFileException

        raise UIFileException(self._ui_file, message, detail=detail)



"""
bubbleswidget.py

A PyQt custom widget example for Qt Designer.

Copyright (C) 2006 David Boddie <david@boddie.org.uk>
Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
"""

import random

from PyQt6.QtCore import (pyqtProperty, pyqtSignal, pyqtSlot, QPointF, QRectF,
        QSize, QSizeF, Qt, QTimer)
from PyQt6.QtGui import QBrush, QColor, QPainter, QPen, QRadialGradient
from PyQt6.QtWidgets import QApplication, QWidget


class BaseClass(QWidget):
    """BaseClass(QWidget)

    Provides a base custom widget class to show that properties implemented
    in Python can be inherited and shown as belonging to distinct classes
    in Qt Designer's Property Editor.
    """

    def __init__(self, parent=None):

        super().__init__(parent)

        self.resetAuthor()

    # Define getter, setter and resetter methods for the author property.

    def getAuthor(self):
        return self._author

    def setAuthor(self, name):
        self._author = name

    def resetAuthor(self):
        self._author = "David Boddie"

    author = pyqtProperty(str, getAuthor, setAuthor, resetAuthor)


class Bubble:
    """Bubble

    Provides a class to represent individual bubbles in a BubblesWidget.
    Each Bubble instance can render itself onto a paint device using a
    QPainter passed to its drawBubble() method.
    """

    def __init__(self, position, radius, speed, innerColor, outerColor):

        self.position = position
        self.radius = radius
        self.speed = speed
        self.innerColor = innerColor
        self.outerColor = outerColor
        self.updateBrush()

    def updateBrush(self):

        gradient = QRadialGradient(
                QPointF(self.radius, self.radius), self.radius,
                QPointF(self.radius*0.5, self.radius*0.5))

        gradient.setColorAt(0, QColor(255, 255, 255, 255))
        gradient.setColorAt(0.25, self.innerColor)
        gradient.setColorAt(1, self.outerColor)
        self.brush = QBrush(gradient)

    def drawBubble(self, painter):

        painter.save()
        painter.translate(self.position.x() - self.radius,
                          self.position.y() - self.radius)
        painter.setBrush(self.brush)
        painter.drawEllipse(0, 0, int(2*self.radius), int(2*self.radius))
        painter.restore()


class BubblesWidget(BaseClass):
    """BubblesWidget(BaseClass)

    Provides a custom widget that shows a number of rising bubbles.
    Various properties are defined so that the user can customize the
    appearance of the widget, and change the number and behaviour of the
    bubbles shown.
    """

    # We define two signals that are used to indicate changes to the status
    # of the widget.
    bubbleLeft = pyqtSignal()
    bubblesRemaining = pyqtSignal(int)

    def __init__(self, parent=None):

        super().__init__(parent)

        self.pen = QPen(QColor("#cccccc"))
        self.bubbles = []
        self.backgroundColor1 = self.randomColor()
        self.backgroundColor2 = self.randomColor().darker(150)
        self.newBubble = None

        random.seed()

        self.animation_timer = QTimer(self)
        self.animation_timer.setSingleShot(False)
        self.animation_timer.timeout.connect(self.animate)
        self.animation_timer.start(25)

        self.bubbleTimer = QTimer()
        self.bubbleTimer.setSingleShot(False)
        self.bubbleTimer.timeout.connect(self.expandBubble)

        self.setMouseTracking(True)
        self.setMinimumSize(QSize(200, 200))
        self.setWindowTitle("Bubble Maker")

    def paintEvent(self, event):

        background = QRadialGradient(QPointF(self.rect().topLeft()), 500,
                QPointF(self.rect().bottomRight()))
        background.setColorAt(0, self.backgroundColor1)
        background.setColorAt(1, self.backgroundColor2)

        painter = QPainter()
        painter.begin(self)
        painter.setRenderHint(QPainter.RenderHint.Antialiasing)
        painter.fillRect(event.rect(), QBrush(background))

        painter.setPen(self.pen)

        for bubble in self.bubbles:

            if QRectF(bubble.position - QPointF(bubble.radius, bubble.radius),
                      QSizeF(2*bubble.radius, 2*bubble.radius)).intersects(QRectF(event.rect())):
                bubble.drawBubble(painter)

        if self.newBubble:

            self.newBubble.drawBubble(painter)

        painter.end()

    def mousePressEvent(self, event):

        if event.button() == Qt.MouseButton.LeftButton and self.newBubble is None:

            self.newBubble = Bubble(QPointF(event.position()), 4.0,
                                    1.0 + random.random() * 7,
                                    self.randomColor(), self.randomColor())
            self.bubbleTimer.start(50)
            event.accept()

    def mouseMoveEvent(self, event):

        if self.newBubble:

            self.update(
                QRectF(self.newBubble.position - \
                       QPointF(self.newBubble.radius + 1, self.newBubble.radius + 1),
                       QSizeF(2*self.newBubble.radius + 2, 2*self.newBubble.radius + 2)).toRect()
                )
            self.newBubble.position = QPointF(event.position())
            self.update(
                QRectF(self.newBubble.position - \
                       QPointF(self.newBubble.radius + 1, self.newBubble.radius + 1),
                       QSizeF(2*self.newBubble.radius + 2, 2*self.newBubble.radius + 2)).toRect()
                )

        event.accept()

    def mouseReleaseEvent(self, event):

        if self.newBubble:

            self.bubbles.append(self.newBubble)
            self.newBubble = None
            self.bubbleTimer.stop()
            self.bubblesRemaining.emit(len(self.bubbles))

        event.accept()

    def expandBubble(self):

        if self.newBubble:

            self.newBubble.radius = min(self.newBubble.radius + 4.0,
                                        self.width()/8.0, self.height()/8.0)
            self.update(
                QRectF(self.newBubble.position - \
                       QPointF(self.newBubble.radius + 1, self.newBubble.radius + 1),
                       QSizeF(2*self.newBubble.radius + 2, 2*self.newBubble.radius + 2)).toRect()
                )
            self.newBubble.updateBrush()

    def randomColor(self):

        red = int(205 + random.random() * 50)
        green = int(205 + random.random() * 50)
        blue = int(205 + random.random() * 50)
        alpha = int(91 + random.random() * 100)

        return QColor(red, green, blue, alpha)

    def animate(self):

        bubbles = []
        left = False
        for bubble in self.bubbles:

            bubble.position = bubble.position + QPointF(0, -bubble.speed)

            self.update(
                    QRectF(bubble.position - QPointF(bubble.radius + 1,
                                    bubble.radius + 1),
                            QSizeF(2*bubble.radius + 2, 2*bubble.radius + 2 + bubble.speed)).toRect())

            if bubble.position.y() + bubble.radius > 0:
                bubbles.append(bubble)
            else:
                self.bubbleLeft.emit()
                left = True

        if self.newBubble:
            self.update(
                    QRectF(self.newBubble.position - QPointF(
                                    self.newBubble.radius + 1,
                                    self.newBubble.radius + 1),
                            QSizeF(2*self.newBubble.radius + 2, 2*self.newBubble.radius + 2)).toRect())

        self.bubbles = bubbles
        if left:
            self.bubblesRemaining.emit(len(self.bubbles))

    def sizeHint(self):

        return QSize(200, 200)

    # We provide getter and setter methods for the numberOfBubbles property.
    def getBubbles(self):

        return len(self.bubbles)

    # The setBubbles() method can also be used as a slot.
    @pyqtSlot(int)
    def setBubbles(self, value):

        value = max(0, value)

        while len(self.bubbles) < value:

            newBubble = Bubble(QPointF(random.random() * self.width(),
                                       random.random() * self.height()),
                               4.0 + random.random() * 20,
                               1.0 + random.random() * 7,
                               self.randomColor(), self.randomColor())
            newBubble.updateBrush()
            self.bubbles.append(newBubble)

        self.bubbles = self.bubbles[:value]
        self.bubblesRemaining.emit(value)
        self.update()

    numberOfBubbles = pyqtProperty(int, getBubbles, setBubbles)

    # We provide getter and setter methods for the color1 and color2
    # properties. The red, green and blue components for the QColor
    # values stored in these properties can be edited individually in
    # Qt Designer.

    def getColor1(self):

        return self.backgroundColor1

    def setColor1(self, value):

        self.backgroundColor1 = QColor(value)
        self.update()

    color1 = pyqtProperty(QColor, getColor1, setColor1)

    def getColor2(self):

        return self.backgroundColor2

    def setColor2(self, value):

        self.backgroundColor2 = QColor(value)
        self.update()

    color2 = pyqtProperty(QColor, getColor2, setColor2)

    # The stop() and start() slots provide simple control over the animation
    # of the bubbles in the widget.

    @pyqtSlot()
    def stop(self):

        self.animation_timer.stop()

    @pyqtSlot()
    def start(self):

        self.animation_timer.start(25)


if __name__ == "__main__":

    import sys

    app = QApplication(sys.argv)
    widget = BubblesWidget()
    widget.show()
    sys.exit(app.exec())



#############################################################################
##
## Copyright (C) 2021 Riverbank Computing Limited
## Copyright (C) 2010 Hans-Peter Jansen <hpj@urpla.net>.
## Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
## All rights reserved.
##
## This file is part of the examples of PyQt.
##
## $QT_BEGIN_LICENSE:BSD$
## You may use this file under the terms of the BSD license as follows:
##
## "Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions are
## met:
##   * Redistributions of source code must retain the above copyright
##     notice, this list of conditions and the following disclaimer.
##   * Redistributions in binary form must reproduce the above copyright
##     notice, this list of conditions and the following disclaimer in
##     the documentation and/or other materials provided with the
##     distribution.
##   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
##     the names of its contributors may be used to endorse or promote
##     products derived from this software without specific prior written
##     permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
## A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
## OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
## SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
## LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
## DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
## THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
## (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
## OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
## $QT_END_LICENSE$
##
#############################################################################


from PyQt6.QtCore import pyqtSignal, QMimeData, Qt
from PyQt6.QtGui import QPalette, QPixmap
from PyQt6.QtWidgets import (QAbstractItemView, QApplication, QDialogButtonBox,
        QFrame, QLabel, QPushButton, QTableWidget, QTableWidgetItem,
        QVBoxLayout, QWidget)


class DropArea(QLabel):

    changed = pyqtSignal(QMimeData)

    def __init__(self, parent = None):
        super().__init__(parent)

        self.setMinimumSize(200, 200)
        self.setFrameStyle(QFrame.Shadow.Sunken | QFrame.Shape.StyledPanel)
        self.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self.setAcceptDrops(True)
        self.setAutoFillBackground(True)
        self.clear()

    def dragEnterEvent(self, event):
        self.setText("<drop content>")
        self.setBackgroundRole(QPalette.ColorRole.Highlight)
        event.acceptProposedAction()
        self.changed.emit(event.mimeData())

    def dragMoveEvent(self, event):
        event.acceptProposedAction()

    def dropEvent(self, event):
        mimeData = event.mimeData()
        if mimeData.hasImage():
            self.setPixmap(QPixmap(mimeData.imageData()))
        elif mimeData.hasHtml():
            self.setText(mimeData.html())
            self.setTextFormat(Qt.TextFormat.RichText)
        elif mimeData.hasText():
            self.setText(mimeData.text())
            self.setTextFormat(Qt.TextFormat.PlainText)
        elif mimeData.hasUrls():
            self.setText("\n".join([url.path() for url in mimeData.urls()]))
        else:
            self.setText("Cannot display data")

        self.setBackgroundRole(QPalette.ColorRole.Dark)
        event.acceptProposedAction()

    def dragLeaveEvent(self, event):
        self.clear()
        event.accept()

    def clear(self):
        self.setText("<drop content>")
        self.setBackgroundRole(QPalette.ColorRole.Dark)
        self.changed.emit(None)


class DropSiteWindow(QWidget):

    def __init__(self):
        super().__init__()

        self.abstractLabel = QLabel(
                "This example accepts drags from other applications and "
                "displays the MIME types provided by the drag object.")
        self.abstractLabel.setWordWrap(True)
        self.abstractLabel.adjustSize()

        self.dropArea = DropArea()
        self.dropArea.changed.connect(self.updateFormatsTable)

        self.formatsTable = QTableWidget()
        self.formatsTable.setColumnCount(2)
        self.formatsTable.setEditTriggers(
                QAbstractItemView.EditTrigger.NoEditTriggers)
        self.formatsTable.setHorizontalHeaderLabels(["Format", "Content"])
        self.formatsTable.horizontalHeader().setStretchLastSection(True)

        self.clearButton = QPushButton("Clear")
        self.quitButton = QPushButton("Quit")

        self.buttonBox = QDialogButtonBox()
        self.buttonBox.addButton(self.clearButton,
                QDialogButtonBox.ButtonRole.ActionRole)
        self.buttonBox.addButton(self.quitButton,
                QDialogButtonBox.ButtonRole.RejectRole)

        self.quitButton.pressed.connect(self.close)
        self.clearButton.pressed.connect(self.dropArea.clear)

        mainLayout = QVBoxLayout()
        mainLayout.addWidget(self.abstractLabel)
        mainLayout.addWidget(self.dropArea)
        mainLayout.addWidget(self.formatsTable)
        mainLayout.addWidget(self.buttonBox)
        self.setLayout(mainLayout)

        self.setWindowTitle("Drop Site")
        self.setMinimumSize(350, 500)

    def updateFormatsTable(self, mimeData=None):
        self.formatsTable.setRowCount(0)

        if mimeData is None:
            return

        for format in mimeData.formats():
            formatItem = QTableWidgetItem(format)
            formatItem.setFlags(Qt.ItemFlag.ItemIsEnabled)
            formatItem.setTextAlignment(
                    Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignLeft)

            if format == 'text/plain':
                text = mimeData.text().strip()
            elif format == 'text/html':
                text = mimeData.html().strip()
            elif format == 'text/uri-list':
                text = " ".join([url.toString() for url in mimeData.urls()])
            else:
                text = " ".join(["%02X" % ord(datum) for datum in mimeData.data(format)])

            row = self.formatsTable.rowCount()
            self.formatsTable.insertRow(row)
            self.formatsTable.setItem(row, 0, QTableWidgetItem(format))
            self.formatsTable.setItem(row, 1, QTableWidgetItem(text))

        self.formatsTable.resizeColumnToContents(0)


if __name__ == '__main__':

    import sys

    app = QApplication(sys.argv)
    window = DropSiteWindow()
    window.show()
    sys.exit(app.exec())



# Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
# 
# This file is part of PyQt6.
# 
# This file may be used under the terms of the GNU General Public License
# version 3.0 as published by the Free Software Foundation and appearing in
# the file LICENSE included in the packaging of this file.  Please review the
# following information to ensure the GNU General Public License version 3.0
# requirements will be met: http://www.gnu.org/copyleft/gpl.html.
# 
# If you do not wish to use this file under the terms of the GPL version 3.0
# then you may purchase a commercial license.  For more information contact
# info@riverbankcomputing.com.
# 
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


class Context:
    """ Encapsulate a message context. """

    def __init__(self, name):
        """ Initialise the context. """

        self.name = name
        self.messages = []


class EmbeddedComments:
    """ Encapsulate information for a translator embedded in comments. """

    def __init__(self):
        """ Initialise the object. """

        self.message_id = ''
        self.extra_comments = []
        self.extras = []


class Message:
    """ Encapsulate a message. """

    def __init__(self, filename, line_nr, source, comment, numerus):
        """ Initialise the message. """

        self.filename = filename
        self.line_nr = line_nr
        self.source = source
        self.comment = comment
        self.numerus = numerus
        self.embedded_comments = EmbeddedComments()
